summaryrefslogtreecommitdiffstats
path: root/krecipes/src/dialogs
diff options
context:
space:
mode:
Diffstat (limited to 'krecipes/src/dialogs')
-rw-r--r--krecipes/src/dialogs/advancedsearchdialog.cpp24
-rw-r--r--krecipes/src/dialogs/advancedsearchdialog.h6
-rw-r--r--krecipes/src/dialogs/authorsdialog.cpp4
-rw-r--r--krecipes/src/dialogs/authorsdialog.h4
-rw-r--r--krecipes/src/dialogs/borderdialog.cpp14
-rw-r--r--krecipes/src/dialogs/borderdialog.h10
-rw-r--r--krecipes/src/dialogs/categorieseditordialog.cpp4
-rw-r--r--krecipes/src/dialogs/categorieseditordialog.h4
-rw-r--r--krecipes/src/dialogs/conversiondialog.cpp2
-rw-r--r--krecipes/src/dialogs/createcategorydialog.cpp2
-rw-r--r--krecipes/src/dialogs/createelementdialog.cpp2
-rw-r--r--krecipes/src/dialogs/createingredientweightdialog.cpp4
-rw-r--r--krecipes/src/dialogs/createpropertydialog.cpp2
-rw-r--r--krecipes/src/dialogs/createunitdialog.cpp2
-rw-r--r--krecipes/src/dialogs/dbimportdialog.cpp4
-rw-r--r--krecipes/src/dialogs/dependanciesdialog.cpp14
-rw-r--r--krecipes/src/dialogs/dependanciesdialog.h4
-rw-r--r--krecipes/src/dialogs/dietviewdialog.cpp4
-rw-r--r--krecipes/src/dialogs/dietviewdialog.h6
-rw-r--r--krecipes/src/dialogs/dietwizarddialog.cpp46
-rw-r--r--krecipes/src/dialogs/dietwizarddialog.h2
-rw-r--r--krecipes/src/dialogs/editratingdialog.cpp20
-rw-r--r--krecipes/src/dialogs/editratingdialog.h2
-rw-r--r--krecipes/src/dialogs/ingredientgroupsdialog.cpp2
-rw-r--r--krecipes/src/dialogs/ingredientmatcherdialog.cpp34
-rw-r--r--krecipes/src/dialogs/ingredientmatcherdialog.h2
-rw-r--r--krecipes/src/dialogs/ingredientparserdialog.cpp14
-rw-r--r--krecipes/src/dialogs/ingredientparserdialog.h4
-rw-r--r--krecipes/src/dialogs/ingredientsdialog.cpp22
-rw-r--r--krecipes/src/dialogs/pagesetupdialog.cpp46
-rw-r--r--krecipes/src/dialogs/pagesetupdialog.h4
-rw-r--r--krecipes/src/dialogs/prepmethodsdialog.cpp4
-rw-r--r--krecipes/src/dialogs/prepmethodsdialog.h4
-rw-r--r--krecipes/src/dialogs/propertiesdialog.cpp8
-rw-r--r--krecipes/src/dialogs/propertiesdialog.h2
-rw-r--r--krecipes/src/dialogs/recipeimportdialog.cpp6
-rw-r--r--krecipes/src/dialogs/recipeimportdialog.h4
-rw-r--r--krecipes/src/dialogs/recipeinputdialog.cpp42
-rw-r--r--krecipes/src/dialogs/recipeinputdialog.h4
-rw-r--r--krecipes/src/dialogs/recipeprintpreview.cpp2
-rw-r--r--krecipes/src/dialogs/recipeviewdialog.cpp24
-rw-r--r--krecipes/src/dialogs/recipeviewdialog.h4
-rw-r--r--krecipes/src/dialogs/refineshoppinglistdialog.cpp24
-rw-r--r--krecipes/src/dialogs/resizerecipedialog.cpp4
-rw-r--r--krecipes/src/dialogs/selectauthorsdialog.cpp20
-rw-r--r--krecipes/src/dialogs/selectauthorsdialog.h6
-rw-r--r--krecipes/src/dialogs/selectcategoriesdialog.cpp4
-rw-r--r--krecipes/src/dialogs/selectcategoriesdialog.h2
-rw-r--r--krecipes/src/dialogs/selectpropertydialog.cpp10
-rw-r--r--krecipes/src/dialogs/selectpropertydialog.h4
-rw-r--r--krecipes/src/dialogs/selectrecipedialog.cpp22
-rw-r--r--krecipes/src/dialogs/selectrecipedialog.h6
-rw-r--r--krecipes/src/dialogs/selectunitdialog.cpp10
-rw-r--r--krecipes/src/dialogs/selectunitdialog.h4
-rw-r--r--krecipes/src/dialogs/setupdisplay.cpp26
-rw-r--r--krecipes/src/dialogs/setupdisplay.h10
-rw-r--r--krecipes/src/dialogs/shoppinglistdialog.cpp34
-rw-r--r--krecipes/src/dialogs/shoppinglistdialog.h2
-rw-r--r--krecipes/src/dialogs/shoppinglistviewdialog.cpp10
-rw-r--r--krecipes/src/dialogs/shoppinglistviewdialog.h6
-rw-r--r--krecipes/src/dialogs/similarcategoriesdialog.cpp10
-rw-r--r--krecipes/src/dialogs/similarcategoriesdialog.h6
-rw-r--r--krecipes/src/dialogs/unitsdialog.cpp6
-rw-r--r--krecipes/src/dialogs/unitsdialog.h2
-rw-r--r--krecipes/src/dialogs/usdadatadialog.cpp6
-rw-r--r--krecipes/src/dialogs/usdadatadialog.h4
66 files changed, 328 insertions, 328 deletions
diff --git a/krecipes/src/dialogs/advancedsearchdialog.cpp b/krecipes/src/dialogs/advancedsearchdialog.cpp
index 7fc78e6..87b6cea 100644
--- a/krecipes/src/dialogs/advancedsearchdialog.cpp
+++ b/krecipes/src/dialogs/advancedsearchdialog.cpp
@@ -33,15 +33,15 @@
#include <ntqradiobutton.h>
#include <ntqbuttongroup.h>
-#include <kapplication.h>
+#include <tdeapplication.h>
#include <kcursor.h>
#include <kdebug.h>
#include <kiconloader.h>
-#include <klistview.h>
-#include <klocale.h>
-#include <kconfig.h>
-#include <kglobal.h>
-#include <kpopupmenu.h>
+#include <tdelistview.h>
+#include <tdelocale.h>
+#include <tdeconfig.h>
+#include <tdeglobal.h>
+#include <tdepopupmenu.h>
#include "backends/recipedb.h"
#include "backends/searchparameters.h"
@@ -412,7 +412,7 @@ AdvancedSearchDialog::AdvancedSearchDialog( TQWidget *parent, RecipeDB *db ) : T
#endif
criterionFrameLayout->addLayout( layout12 );
- criteriaListView = new KListView( criterionFrame, "criteriaListView" );
+ criteriaListView = new TDEListView( criterionFrame, "criteriaListView" );
criteriaListView->setSizePolicy( TQSizePolicy::Preferred, TQSizePolicy::Minimum );
criteriaListView->addColumn( i18n( "Criterion" ) );
criteriaListView->addColumn( i18n( "Stars" ) );
@@ -441,7 +441,7 @@ AdvancedSearchDialog::AdvancedSearchDialog( TQWidget *parent, RecipeDB *db ) : T
layout7->addLayout( layout9 );
AdvancedSearchDialogLayout->addLayout( layout7 );
- resultsListView = new KListView( this, "resultsListView" );
+ resultsListView = new TDEListView( this, "resultsListView" );
resultsListView->setSelectionMode( TQListView::Extended );
resultsListView->setSizePolicy( TQSizePolicy( (TQSizePolicy::SizeType)7, (TQSizePolicy::SizeType)7, 0, 1, resultsListView->sizePolicy().hasHeightForWidth() ) );
AdvancedSearchDialogLayout->addWidget( resultsListView );
@@ -459,7 +459,7 @@ AdvancedSearchDialog::AdvancedSearchDialog( TQWidget *parent, RecipeDB *db ) : T
scrollView1->setHScrollBarMode( TQScrollView::AlwaysOff );
scrollView1->setResizePolicy( TQScrollView::AutoOneFit );
- KConfig *config = KGlobal::config();
+ TDEConfig *config = TDEGlobal::config();
config->setGroup( "Advanced" );
bool show_id = config->readBoolEntry( "ShowID", false );
resultsListView->addColumn( i18n( "Title" ) );
@@ -529,7 +529,7 @@ AdvancedSearchDialog::AdvancedSearchDialog( TQWidget *parent, RecipeDB *db ) : T
clear();
- KPopupMenu *kpop = new KPopupMenu( criteriaListView );
+ TDEPopupMenu *kpop = new TDEPopupMenu( criteriaListView );
kpop->insertItem( i18n( "&Delete" ), this, SLOT( slotRemoveRatingCriteria() ), Key_Delete );
}
@@ -659,7 +659,7 @@ void AdvancedSearchDialog::buttonSwitched()
void AdvancedSearchDialog::search()
{
- KApplication::setOverrideCursor( KCursor::waitCursor() );
+ TDEApplication::setOverrideCursor( KCursor::waitCursor() );
//we need to load more than just the title because we'll be doing further refining of the search
int load_items = RecipeDB::Title | RecipeDB::NamesOnly | RecipeDB::Noatime;
@@ -877,7 +877,7 @@ void AdvancedSearchDialog::search()
( void ) new TQListViewItem( resultsListView, "--- "+i18n("No matching recipes found")+" ---");
}
- KApplication::restoreOverrideCursor();
+ TDEApplication::restoreOverrideCursor();
}
TQStringList AdvancedSearchDialog::split( const TQString &text, bool sql_wildcards ) const
diff --git a/krecipes/src/dialogs/advancedsearchdialog.h b/krecipes/src/dialogs/advancedsearchdialog.h
index afb9244..9fb1011 100644
--- a/krecipes/src/dialogs/advancedsearchdialog.h
+++ b/krecipes/src/dialogs/advancedsearchdialog.h
@@ -27,7 +27,7 @@ class TQComboBox;
class TQSpinBox;
class TQTimeEdit;
class KPushButton;
-class KListView;
+class TDEListView;
class TQListViewItem;
class TQRadioButton;
class TQButtonGroup;
@@ -97,7 +97,7 @@ protected:
TQFrame* instructionsFrame;
KPushButton* clearButton;
KPushButton* findButton;
- KListView* resultsListView;
+ TDEListView* resultsListView;
TQCheckBox *requireAllTitle;
TQCheckBox *requireAllInstructions;
KDateEdit *createdStartDateEdit;
@@ -116,7 +116,7 @@ protected:
FractionInput* starsWidget;
TQPushButton* addCriteriaButton;
TQPushButton* removeCriteriaButton;
- KListView* criteriaListView;
+ TDEListView* criteriaListView;
TQPushButton* ratingsButton;
TQButtonGroup *ratingButtonGroup;
TQFrame *ratingAvgFrame;
diff --git a/krecipes/src/dialogs/authorsdialog.cpp b/krecipes/src/dialogs/authorsdialog.cpp
index 1622dfa..2cdbedb 100644
--- a/krecipes/src/dialogs/authorsdialog.cpp
+++ b/krecipes/src/dialogs/authorsdialog.cpp
@@ -16,8 +16,8 @@
#include "widgets/authorlistview.h"
#include <kdialog.h>
-#include <klocale.h>
-#include <kmessagebox.h>
+#include <tdelocale.h>
+#include <tdemessagebox.h>
AuthorsDialog::AuthorsDialog( TQWidget* parent, RecipeDB *db ) : TQWidget( parent )
{
diff --git a/krecipes/src/dialogs/authorsdialog.h b/krecipes/src/dialogs/authorsdialog.h
index 9e4cae9..d71bc93 100644
--- a/krecipes/src/dialogs/authorsdialog.h
+++ b/krecipes/src/dialogs/authorsdialog.h
@@ -18,7 +18,7 @@
#include <ntqhbox.h>
#include <ntqlayout.h>
#include <kiconloader.h>
-#include <klistview.h>
+#include <tdelistview.h>
#include "widgets/dblistviewbase.h"
@@ -46,6 +46,6 @@ private:
StdAuthorListView *authorListView;
TQPushButton *newAuthorButton;
TQPushButton *removeAuthorButton;
- KIconLoader *il;
+ TDEIconLoader *il;
};
#endif
diff --git a/krecipes/src/dialogs/borderdialog.cpp b/krecipes/src/dialogs/borderdialog.cpp
index ee86575..95f14a3 100644
--- a/krecipes/src/dialogs/borderdialog.cpp
+++ b/krecipes/src/dialogs/borderdialog.cpp
@@ -20,10 +20,10 @@
#include <ntqwhatsthis.h>
#include <kdebug.h>
-#include <khtml_part.h>
-#include <khtmlview.h>
-#include <klistbox.h>
-#include <klocale.h>
+#include <tdehtml_part.h>
+#include <tdehtmlview.h>
+#include <tdelistbox.h>
+#include <tdelocale.h>
#include "datablocks/kreborder.h"
@@ -47,7 +47,7 @@ BorderDialog::BorderDialog( const KreBorder &border, TQWidget* parent, const cha
styleLabel = new TQLabel( borderGroupBox, "styleLabel" );
layout3->addWidget( styleLabel );
- styleListBox = new KListBox( borderGroupBox, "styleListBox" );
+ styleListBox = new TDEListBox( borderGroupBox, "styleListBox" );
layout3->addWidget( styleListBox );
layout4->addLayout( layout3 );
@@ -78,12 +78,12 @@ BorderDialog::BorderDialog( const KreBorder &border, TQWidget* parent, const cha
widthSpinBox->setMinValue( 1 );
layout1->addWidget( widthSpinBox );
- widthListBox = new KListBox( borderGroupBox, "widthListBox" );
+ widthListBox = new TDEListBox( borderGroupBox, "widthListBox" );
layout1->addWidget( widthListBox );
layout4->addLayout( layout1 );
borderGroupBoxLayout->addLayout( layout4 );
- borderPreview = new KHTMLPart( borderGroupBox );
+ borderPreview = new TDEHTMLPart( borderGroupBox );
borderPreview->view() ->setSizePolicy( TQSizePolicy::Preferred, TQSizePolicy::Fixed );
borderGroupBoxLayout->addWidget( borderPreview->view() );
diff --git a/krecipes/src/dialogs/borderdialog.h b/krecipes/src/dialogs/borderdialog.h
index 7ea169f..d1a9164 100644
--- a/krecipes/src/dialogs/borderdialog.h
+++ b/krecipes/src/dialogs/borderdialog.h
@@ -20,10 +20,10 @@ class TQGridLayout;
class TQSpacerItem;
class TQGroupBox;
class TQLabel;
-class KListBox;
+class TDEListBox;
class TQListBoxItem;
class TQSpinBox;
-class KHTMLPart;
+class TDEHTMLPart;
class KreBorder;
@@ -39,14 +39,14 @@ public:
TQGroupBox* borderGroupBox;
TQLabel* styleLabel;
- KListBox* styleListBox;
+ TDEListBox* styleListBox;
TQLabel* colorLabel;
KHSSelector* hsSelector;
KValueSelector* valuePal;
TQLabel* widthLabel;
TQSpinBox* widthSpinBox;
- KListBox* widthListBox;
- KHTMLPart* borderPreview;
+ TDEListBox* widthListBox;
+ TDEHTMLPart* borderPreview;
protected:
TQVBoxLayout* borderGroupBoxLayout;
diff --git a/krecipes/src/dialogs/categorieseditordialog.cpp b/krecipes/src/dialogs/categorieseditordialog.cpp
index d4d7195..0ca574b 100644
--- a/krecipes/src/dialogs/categorieseditordialog.cpp
+++ b/krecipes/src/dialogs/categorieseditordialog.cpp
@@ -14,8 +14,8 @@
#include <kdebug.h>
#include <kdialog.h>
-#include <klocale.h>
-#include <kmessagebox.h>
+#include <tdelocale.h>
+#include <tdemessagebox.h>
#include "widgets/categorylistview.h"
#include "createcategorydialog.h"
diff --git a/krecipes/src/dialogs/categorieseditordialog.h b/krecipes/src/dialogs/categorieseditordialog.h
index 58bcc7f..3984132 100644
--- a/krecipes/src/dialogs/categorieseditordialog.h
+++ b/krecipes/src/dialogs/categorieseditordialog.h
@@ -18,7 +18,7 @@
#include <ntqhbox.h>
#include <ntqlayout.h>
#include <kiconloader.h>
-#include <klistview.h>
+#include <tdelistview.h>
#include "datablocks/categorytree.h"
#include "widgets/dblistviewbase.h"
@@ -50,7 +50,7 @@ private:
TQHBox *buttonBar;
TQPushButton *newCategoryButton;
TQPushButton *removeCategoryButton;
- KIconLoader *il;
+ TDEIconLoader *il;
};
#endif
diff --git a/krecipes/src/dialogs/conversiondialog.cpp b/krecipes/src/dialogs/conversiondialog.cpp
index 78edc09..90d590f 100644
--- a/krecipes/src/dialogs/conversiondialog.cpp
+++ b/krecipes/src/dialogs/conversiondialog.cpp
@@ -22,7 +22,7 @@
#include <kcombobox.h>
#include <klineedit.h>
-#include <klocale.h>
+#include <tdelocale.h>
#include "backends/recipedb.h"
#include "widgets/unitcombobox.h"
diff --git a/krecipes/src/dialogs/createcategorydialog.cpp b/krecipes/src/dialogs/createcategorydialog.cpp
index d871fd9..e55180f 100644
--- a/krecipes/src/dialogs/createcategorydialog.cpp
+++ b/krecipes/src/dialogs/createcategorydialog.cpp
@@ -20,7 +20,7 @@
#include <kcombobox.h>
#include <klineedit.h>
-#include <klocale.h>
+#include <tdelocale.h>
CreateCategoryDialog::CreateCategoryDialog( TQWidget *parent, const ElementList& categories )
: KDialogBase( parent, "createCategoryDialog", true, i18n( "New Category" ),
diff --git a/krecipes/src/dialogs/createelementdialog.cpp b/krecipes/src/dialogs/createelementdialog.cpp
index a129f78..1f5b4a0 100644
--- a/krecipes/src/dialogs/createelementdialog.cpp
+++ b/krecipes/src/dialogs/createelementdialog.cpp
@@ -12,7 +12,7 @@
#include "createelementdialog.h"
-#include <klocale.h>
+#include <tdelocale.h>
CreateElementDialog::CreateElementDialog( TQWidget *parent, const TQString &text )
: KDialogBase( parent, "createElementDialog", true, text,
diff --git a/krecipes/src/dialogs/createingredientweightdialog.cpp b/krecipes/src/dialogs/createingredientweightdialog.cpp
index 0f3262b..4bc52d1 100644
--- a/krecipes/src/dialogs/createingredientweightdialog.cpp
+++ b/krecipes/src/dialogs/createingredientweightdialog.cpp
@@ -18,8 +18,8 @@
#include <ntqwhatsthis.h>
#include <ntqvbox.h>
-#include <kmessagebox.h>
-#include <klocale.h>
+#include <tdemessagebox.h>
+#include <tdelocale.h>
#include "widgets/unitcombobox.h"
#include "widgets/prepmethodcombobox.h"
diff --git a/krecipes/src/dialogs/createpropertydialog.cpp b/krecipes/src/dialogs/createpropertydialog.cpp
index 44f7584..9f8f107 100644
--- a/krecipes/src/dialogs/createpropertydialog.cpp
+++ b/krecipes/src/dialogs/createpropertydialog.cpp
@@ -12,7 +12,7 @@
#include "createpropertydialog.h"
-#include <klocale.h>
+#include <tdelocale.h>
CreatePropertyDialog::CreatePropertyDialog( TQWidget *parent, UnitList* list )
: KDialogBase( parent, "createPropertyDialog", true, i18n( "New Property" ),
diff --git a/krecipes/src/dialogs/createunitdialog.cpp b/krecipes/src/dialogs/createunitdialog.cpp
index 224f65d..483c200 100644
--- a/krecipes/src/dialogs/createunitdialog.cpp
+++ b/krecipes/src/dialogs/createunitdialog.cpp
@@ -14,7 +14,7 @@
#include <ntqlabel.h>
-#include <klocale.h>
+#include <tdelocale.h>
#include <klineedit.h>
#include <kcombobox.h>
diff --git a/krecipes/src/dialogs/dbimportdialog.cpp b/krecipes/src/dialogs/dbimportdialog.cpp
index 187eee3..5b3b18a 100644
--- a/krecipes/src/dialogs/dbimportdialog.cpp
+++ b/krecipes/src/dialogs/dbimportdialog.cpp
@@ -29,9 +29,9 @@
#include <ntqwhatsthis.h>
#include <ntqhbox.h>
-#include <kconfig.h>
+#include <tdeconfig.h>
#include <kdebug.h>
-#include <klocale.h>
+#include <tdelocale.h>
#include <kurlrequester.h>
#include <knuminput.h>
diff --git a/krecipes/src/dialogs/dependanciesdialog.cpp b/krecipes/src/dialogs/dependanciesdialog.cpp
index b520d77..d582e49 100644
--- a/krecipes/src/dialogs/dependanciesdialog.cpp
+++ b/krecipes/src/dialogs/dependanciesdialog.cpp
@@ -17,10 +17,10 @@
#include <ntqvbox.h>
-#include <klocale.h>
-#include <kglobal.h>
-#include <kconfig.h>
-#include <kmessagebox.h>
+#include <tdelocale.h>
+#include <tdeglobal.h>
+#include <tdeconfig.h>
+#include <tdemessagebox.h>
DependanciesDialog::DependanciesDialog( TQWidget *parent, const TQValueList<ListInfo> &lists, bool deps_are_deleted ) : KDialogBase( parent, "DependanciesDialog", true, TQString::null,
KDialogBase::Ok | KDialogBase::Cancel, KDialogBase::Cancel ),
@@ -62,7 +62,7 @@ void DependanciesDialog::init( const TQValueList<ListInfo> &lists )
for ( TQValueList<ListInfo>::const_iterator list_it = lists.begin(); list_it != lists.end(); ++list_it ) {
if ( !((*list_it).list).isEmpty() ) {
TQGroupBox *groupBox = new TQGroupBox( 1, TQt::Vertical, (*list_it).name, page );
- KListBox *listBox = new KListBox( groupBox );
+ TDEListBox *listBox = new TDEListBox( groupBox );
loadList( listBox, (*list_it).list );
}
}
@@ -70,9 +70,9 @@ void DependanciesDialog::init( const TQValueList<ListInfo> &lists )
setSizeGripEnabled( true );
}
-void DependanciesDialog::loadList( KListBox* listBox, const ElementList &list )
+void DependanciesDialog::loadList( TDEListBox* listBox, const ElementList &list )
{
- KConfig * config = KGlobal::config();
+ TDEConfig * config = TDEGlobal::config();
config->setGroup( "Advanced" );
bool show_id = config->readBoolEntry( "ShowID", false );
diff --git a/krecipes/src/dialogs/dependanciesdialog.h b/krecipes/src/dialogs/dependanciesdialog.h
index e5c10f9..c03705d 100644
--- a/krecipes/src/dialogs/dependanciesdialog.h
+++ b/krecipes/src/dialogs/dependanciesdialog.h
@@ -18,7 +18,7 @@
#include <ntqgroupbox.h>
#include <ntqlabel.h>
-#include <klistview.h>
+#include <tdelistview.h>
#include <kdialogbase.h>
#include "datablocks/elementlist.h"
@@ -54,7 +54,7 @@ private:
// Methods
void init( const TQValueList<ListInfo> &lists );
- void loadList( KListBox*, const ElementList &list );
+ void loadList( TDEListBox*, const ElementList &list );
};
#endif
diff --git a/krecipes/src/dialogs/dietviewdialog.cpp b/krecipes/src/dialogs/dietviewdialog.cpp
index 17bfc4a..6a09b25 100644
--- a/krecipes/src/dialogs/dietviewdialog.cpp
+++ b/krecipes/src/dialogs/dietviewdialog.cpp
@@ -12,7 +12,7 @@
#include "dietviewdialog.h"
#include <kiconloader.h>
-#include <klocale.h>
+#include <tdelocale.h>
#include <kstandarddirs.h>
DietViewDialog::DietViewDialog( TQWidget *parent, const RecipeList &recipeList, int dayNumber, int mealNumber, const TQValueList <int> &dishNumbers )
@@ -26,7 +26,7 @@ DietViewDialog::DietViewDialog( TQWidget *parent, const RecipeList &recipeList,
TQVBox *page = makeVBoxMainWidget();
// The html part
- dietView = new KHTMLPart( page );
+ dietView = new TDEHTMLPart( page );
setInitialSize( TQSize(350, 450) );
diff --git a/krecipes/src/dialogs/dietviewdialog.h b/krecipes/src/dialogs/dietviewdialog.h
index e0f68bd..5558470 100644
--- a/krecipes/src/dialogs/dietviewdialog.h
+++ b/krecipes/src/dialogs/dietviewdialog.h
@@ -16,8 +16,8 @@
#include <ntqvbox.h>
#include <ntqwidget.h>
-#include <khtml_part.h>
-#include <khtmlview.h>
+#include <tdehtml_part.h>
+#include <tdehtmlview.h>
#include <kdialogbase.h>
#include "datablocks/recipelist.h"
@@ -31,7 +31,7 @@ public:
~DietViewDialog();
private:
// Widgets
- KHTMLPart *dietView;
+ TDEHTMLPart *dietView;
// Private methods
void showDiet( const RecipeList &recipeList, int dayNumber, int mealNumber, const TQValueList <int> &dishNumbers );
diff --git a/krecipes/src/dialogs/dietwizarddialog.h b/krecipes/src/dialogs/dietwizarddialog.h
index 797a824..cc2f135 100644
--- a/krecipes/src/dialogs/dietwizarddialog.h
+++ b/krecipes/src/dialogs/dietwizarddialog.h
@@ -30,7 +30,7 @@
#include <ntqvgroupbox.h>
#include <ntqwidgetstack.h>
-#include <klistview.h>
+#include <tdelistview.h>
#include "datablocks/constraintlist.h"
#include "datablocks/recipelist.h"
diff --git a/krecipes/src/dialogs/editratingdialog.cpp b/krecipes/src/dialogs/editratingdialog.cpp
index fc8d943..73ac893 100644
--- a/krecipes/src/dialogs/editratingdialog.cpp
+++ b/krecipes/src/dialogs/editratingdialog.cpp
@@ -10,7 +10,7 @@
#include "editratingdialog.h"
-#include <klocale.h>
+#include <tdelocale.h>
#include <ntqvariant.h>
#include <ntqpushbutton.h>
@@ -18,7 +18,7 @@
#include <ntqcombobox.h>
#include <knuminput.h>
#include <ntqheader.h>
-#include <klistview.h>
+#include <tdelistview.h>
#include <ntqtextedit.h>
#include <ntqlineedit.h>
#include <ntqlayout.h>
@@ -27,8 +27,8 @@
#include <ntqpainter.h>
#include <ntqvbox.h>
-#include <kpopupmenu.h>
-#include <klocale.h>
+#include <tdepopupmenu.h>
+#include <tdelocale.h>
#include <kiconloader.h>
#include <kdebug.h>
@@ -38,17 +38,17 @@
#include "widgets/ratingwidget.h"
-class RatingCriteriaListView : public KListView
+class RatingCriteriaListView : public TDEListView
{
public:
- RatingCriteriaListView( TQWidget *parent = 0, const char *name = 0 ) : KListView(parent,name){}
+ RatingCriteriaListView( TQWidget *parent = 0, const char *name = 0 ) : TDEListView(parent,name){}
void rename( TQListViewItem *it, int c )
{
if ( c == 1 )
it->setPixmap(c,TQPixmap());
- KListView::rename(it,c);
+ TDEListView::rename(it,c);
}
};
@@ -119,9 +119,9 @@ void EditRatingDialog::init( const ElementList &criteriaList )
connect( addButton, SIGNAL(clicked()), this, SLOT(slotAddRatingCriteria()) );
connect( removeButton, SIGNAL(clicked()), this, SLOT(slotRemoveRatingCriteria()) );
- KIconLoader il;
- KPopupMenu *kpop = new KPopupMenu( criteriaListView );
- kpop->insertItem( il.loadIcon( "editshred", KIcon::NoGroup, 16 ), i18n( "&Delete" ), this, SLOT( slotRemoveRatingCriteria() ), Key_Delete );
+ TDEIconLoader il;
+ TDEPopupMenu *kpop = new TDEPopupMenu( criteriaListView );
+ kpop->insertItem( il.loadIcon( "editshred", TDEIcon::NoGroup, 16 ), i18n( "&Delete" ), this, SLOT( slotRemoveRatingCriteria() ), Key_Delete );
for ( ElementList::const_iterator criteria_it = criteriaList.begin(); criteria_it != criteriaList.end(); ++criteria_it ) {
criteriaComboBox->insertItem( ( *criteria_it ).name );
diff --git a/krecipes/src/dialogs/editratingdialog.h b/krecipes/src/dialogs/editratingdialog.h
index fd62442..06a633f 100644
--- a/krecipes/src/dialogs/editratingdialog.h
+++ b/krecipes/src/dialogs/editratingdialog.h
@@ -21,7 +21,7 @@ class TQLabel;
class TQComboBox;
class KDoubleSpinBox;
class TQPushButton;
-class KListView;
+class TDEListView;
class TQListViewItem;
class TQTextEdit;
class TQLineEdit;
diff --git a/krecipes/src/dialogs/ingredientgroupsdialog.cpp b/krecipes/src/dialogs/ingredientgroupsdialog.cpp
index f43ae4d..0d31f11 100644
--- a/krecipes/src/dialogs/ingredientgroupsdialog.cpp
+++ b/krecipes/src/dialogs/ingredientgroupsdialog.cpp
@@ -14,7 +14,7 @@
#include <ntqlayout.h>
#include <ntqvbox.h>
-#include <klocale.h>
+#include <tdelocale.h>
#include <kdialog.h>
#include "widgets/krelistview.h"
diff --git a/krecipes/src/dialogs/ingredientmatcherdialog.cpp b/krecipes/src/dialogs/ingredientmatcherdialog.cpp
index ae8d6a3..ac5b0f8 100644
--- a/krecipes/src/dialogs/ingredientmatcherdialog.cpp
+++ b/krecipes/src/dialogs/ingredientmatcherdialog.cpp
@@ -27,13 +27,13 @@
#include <ntqlayout.h>
#include <ntqgroupbox.h>
-#include <kapplication.h>
+#include <tdeapplication.h>
#include <kcursor.h>
#include <kiconloader.h>
-#include <klocale.h>
+#include <tdelocale.h>
#include <knuminput.h>
-#include <kconfig.h>
-#include <kglobal.h>
+#include <tdeconfig.h>
+#include <tdeglobal.h>
#include <kdebug.h>
#include <kdialogbase.h>
@@ -59,15 +59,15 @@ IngredientMatcherDialog::IngredientMatcherDialog( TQWidget *parent, RecipeDB *db
TQVBoxLayout *layout1 = new TQVBoxLayout( 0, 0, 6, "layout1" );
- KIconLoader il;
+ TDEIconLoader il;
addButton = new TQPushButton( this, "addButton" );
- addButton->setIconSet( il.loadIconSet( "forward", KIcon::Small ) );
+ addButton->setIconSet( il.loadIconSet( "forward", TDEIcon::Small ) );
addButton->setFixedSize( TQSize( 32, 32 ) );
layout1->addWidget( addButton );
removeButton = new TQPushButton( this, "removeButton" );
- removeButton->setIconSet( il.loadIconSet( "back", KIcon::Small ) );
+ removeButton->setIconSet( il.loadIconSet( "back", TDEIcon::Small ) );
removeButton->setFixedSize( TQSize( 32, 32 ) );
layout1->addWidget( removeButton );
TQSpacerItem *spacer1 = new TQSpacerItem( 51, 191, TQSizePolicy::Minimum, TQSizePolicy::Expanding );
@@ -96,7 +96,7 @@ IngredientMatcherDialog::IngredientMatcherDialog( TQWidget *parent, RecipeDB *db
recipeListView->listView() ->addColumn( i18n( "Title" ) );
- KConfig *config = KGlobal::config();
+ TDEConfig *config = TDEGlobal::config();
config->setGroup( "Advanced" );
bool show_id = config->readBoolEntry( "ShowID", false );
recipeListView->listView() ->addColumn( i18n( "Id" ), show_id ? -1 : 0 );
@@ -111,13 +111,13 @@ IngredientMatcherDialog::IngredientMatcherDialog( TQWidget *parent, RecipeDB *db
TQHBox *buttonBox = new TQHBox( this );
okButton = new TQPushButton( buttonBox );
- okButton->setIconSet( il.loadIconSet( "button_ok", KIcon::Small ) );
+ okButton->setIconSet( il.loadIconSet( "button_ok", TDEIcon::Small ) );
okButton->setText( i18n( "Find matching recipes" ) );
//buttonBox->layout()->addItem( new TQSpacerItem( 10,10, TQSizePolicy::MinimumExpanding, TQSizePolicy::Fixed ) );
clearButton = new TQPushButton( buttonBox );
- clearButton->setIconSet( il.loadIconSet( "editclear", KIcon::Small ) );
+ clearButton->setIconSet( il.loadIconSet( "editclear", TDEIcon::Small ) );
clearButton->setText( i18n( "Clear" ) );
dialogLayout->addWidget(buttonBox);
@@ -234,7 +234,7 @@ void IngredientMatcherDialog::unselectIngredients()
void IngredientMatcherDialog::findRecipes( void )
{
- KApplication::setOverrideCursor( KCursor::waitCursor() );
+ TDEApplication::setOverrideCursor( KCursor::waitCursor() );
START_TIMER("Ingredient Matcher: loading database data");
@@ -274,7 +274,7 @@ void IngredientMatcherDialog::findRecipes( void )
//Check if the user wants to show missing ingredients
if ( missingNumberSpinBox->value() == 0 ) {
- KApplication::restoreOverrideCursor();
+ TDEApplication::restoreOverrideCursor();
return ;
} //"None"
@@ -325,7 +325,7 @@ void IngredientMatcherDialog::findRecipes( void )
}
END_TIMER();
- KApplication::restoreOverrideCursor();
+ TDEApplication::restoreOverrideCursor();
}
void IngredientMatcherDialog::reload( ReloadFlags flag )
@@ -336,16 +336,16 @@ void IngredientMatcherDialog::reload( ReloadFlags flag )
void SectionItem::paintCell ( TQPainter * p, const TQColorGroup & /*cg*/, int column, int width, int /*align*/ )
{
// Draw the section's deco
- p->setPen( KGlobalSettings::activeTitleColor() );
- p->setBrush( KGlobalSettings::activeTitleColor() );
+ p->setPen( TDEGlobalSettings::activeTitleColor() );
+ p->setBrush( TDEGlobalSettings::activeTitleColor() );
p->drawRect( 0, 0, width, height() );
// Draw the section's text
if ( column == 0 ) {
- TQFont titleFont = KGlobalSettings::windowTitleFont ();
+ TQFont titleFont = TDEGlobalSettings::windowTitleFont ();
p->setFont( titleFont );
- p->setPen( KGlobalSettings::activeTextColor() );
+ p->setPen( TDEGlobalSettings::activeTextColor() );
p->drawText( 0, 0, width, height(), TQt::AlignLeft | TQt::AlignVCenter, mText );
}
}
diff --git a/krecipes/src/dialogs/ingredientmatcherdialog.h b/krecipes/src/dialogs/ingredientmatcherdialog.h
index 13fb9c1..e793e3b 100644
--- a/krecipes/src/dialogs/ingredientmatcherdialog.h
+++ b/krecipes/src/dialogs/ingredientmatcherdialog.h
@@ -27,7 +27,7 @@
#include <ntqvbox.h>
#include <kstringhandler.h>
-#include <klocale.h>
+#include <tdelocale.h>
class KreListView;
class KIntSpinBox;
diff --git a/krecipes/src/dialogs/ingredientparserdialog.cpp b/krecipes/src/dialogs/ingredientparserdialog.cpp
index b342eee..f115f1c 100644
--- a/krecipes/src/dialogs/ingredientparserdialog.cpp
+++ b/krecipes/src/dialogs/ingredientparserdialog.cpp
@@ -22,13 +22,13 @@
#include <ntqclipboard.h>
#include <ntqvbox.h>
-#include <klocale.h>
+#include <tdelocale.h>
#include <kdebug.h>
-#include <klistview.h>
+#include <tdelistview.h>
#include <kpushbutton.h>
-#include <kmessagebox.h>
-#include <kaction.h>
-#include <kpopupmenu.h>
+#include <tdemessagebox.h>
+#include <tdeaction.h>
+#include <tdepopupmenu.h>
#include "datablocks/mixednumber.h"
#include "widgets/inglistviewitem.h"
@@ -53,7 +53,7 @@ IngredientParserDialog::IngredientParserDialog( const UnitList &units, TQWidget*
previewLabel = new TQLabel( page, "previewLabel" );
previewLabel->setTextFormat( TQLabel::RichText );
- previewIngView = new KListView( page, "previewIngView" );
+ previewIngView = new TDEListView( page, "previewIngView" );
previewIngView->setSorting(-1);
previewIngView->addColumn( i18n( "Ingredient" ) );
previewIngView->addColumn( i18n( "Amount" ) );
@@ -82,7 +82,7 @@ IngredientParserDialog::IngredientParserDialog( const UnitList &units, TQWidget*
buttonBox->addWidget( buttonGroup );
buttonBox->addItem( horizontalSpacing );
- KPopupMenu *kpop = new KPopupMenu( previewIngView );
+ TDEPopupMenu *kpop = new TDEPopupMenu( previewIngView );
kpop->insertItem( i18n( "&Delete" ), this, SLOT( removeIngredient() ), Key_Delete );
kpop->insertItem( i18n("Set &Header") , this, SLOT( convertToHeader() ) );
diff --git a/krecipes/src/dialogs/ingredientparserdialog.h b/krecipes/src/dialogs/ingredientparserdialog.h
index 5e3909c..6f2bc7f 100644
--- a/krecipes/src/dialogs/ingredientparserdialog.h
+++ b/krecipes/src/dialogs/ingredientparserdialog.h
@@ -24,7 +24,7 @@ class TQLabel;
class TQTextEdit;
class TQLineEdit;
class KPushButton;
-class KListView;
+class TDEListView;
class TQListViewItem;
class TQPushButton;
@@ -43,7 +43,7 @@ protected:
TQLabel *previewLabel;
TQTextEdit* ingredientTextEdit;
KPushButton* parseButton;
- KListView* previewIngView;
+ TDEListView* previewIngView;
TQPushButton* buttonGroup;
protected slots:
diff --git a/krecipes/src/dialogs/ingredientsdialog.cpp b/krecipes/src/dialogs/ingredientsdialog.cpp
index ba1bfa6..768c45e 100644
--- a/krecipes/src/dialogs/ingredientsdialog.cpp
+++ b/krecipes/src/dialogs/ingredientsdialog.cpp
@@ -26,13 +26,13 @@
#include "dialogs/ingredientgroupsdialog.h"
#include "dialogs/createingredientweightdialog.h"
-#include <kapplication.h>
+#include <tdeapplication.h>
#include <kcursor.h>
#include <kdebug.h>
-#include <klocale.h>
-#include <kmessagebox.h>
-#include <kglobal.h>
-#include <kconfig.h>
+#include <tdelocale.h>
+#include <tdemessagebox.h>
+#include <tdeglobal.h>
+#include <tdeconfig.h>
#include <ntqheader.h>
#include <ntqmessagebox.h>
@@ -136,7 +136,7 @@ IngredientsDialog::IngredientsDialog( TQWidget* parent, RecipeDB *db ) : TQWidge
layout->addItem( spacer_Ing_Units, 1, 4 );
- KConfig *config = KGlobal::config();
+ TDEConfig *config = TDEGlobal::config();
config->setGroup( "Advanced" );
bool show_id = config->readBoolEntry( "ShowID", false );
@@ -327,7 +327,7 @@ void IngredientsDialog::reloadUnitList()
if ( ingredientID >= 0 ) {
database->loadPossibleUnits( ingredientID, unitList );
- //Populate this data into the KListView
+ //Populate this data into the TDEListView
for ( UnitList::const_iterator unit_it = unitList->begin(); unit_it != unitList->end(); ++unit_it ) {
if ( !( *unit_it ).name.isEmpty() ) {
@@ -519,7 +519,7 @@ void IngredientsDialog:: reloadPropertyList( void )
TQListViewItem *it;
it = ingredientListView->listView() ->selectedItem();
- //Populate this data into the KListView
+ //Populate this data into the TDEListView
if ( it ) { // make sure that the ingredient list is not empty
database->loadProperties( propertiesList, it->text( 1 ).toInt() ); // load the list for this ingredient
@@ -544,7 +544,7 @@ void IngredientsDialog::reloadWeightList( void )
//If none is selected, select first item
TQListViewItem *it = ingredientListView->listView() ->selectedItem();
- //Populate this data into the KListView
+ //Populate this data into the TDEListView
if ( it ) { // make sure that the ingredient list is not empty
WeightList list = database->ingredientWeightUnits( it->text( 1 ).toInt() ); // load the list for this ingredient
for ( WeightList::const_iterator weight_it = list.begin(); weight_it != list.end(); ++weight_it ) {
@@ -686,9 +686,9 @@ void IngredientsDialog::openUSDADialog( void )
{
TQListViewItem * ing_it = ingredientListView->listView() ->selectedItem(); // Find selected ingredient
if ( ing_it ) {
- KApplication::setOverrideCursor( KCursor::waitCursor() );
+ TDEApplication::setOverrideCursor( KCursor::waitCursor() );
USDADataDialog usda_dialog( Element( ing_it->text( 0 ), ing_it->text( 1 ).toInt() ), database, this );
- KApplication::restoreOverrideCursor();
+ TDEApplication::restoreOverrideCursor();
if ( usda_dialog.exec() == TQDialog::Accepted ) {
reloadPropertyList(); //update property list upon success
diff --git a/krecipes/src/dialogs/pagesetupdialog.cpp b/krecipes/src/dialogs/pagesetupdialog.cpp
index 2586312..f9d004c 100644
--- a/krecipes/src/dialogs/pagesetupdialog.cpp
+++ b/krecipes/src/dialogs/pagesetupdialog.cpp
@@ -20,35 +20,35 @@
#include <ntqtabwidget.h>
#include <ntqlabel.h>
-#include <khtmlview.h>
-#include <kapplication.h>
+#include <tdehtmlview.h>
+#include <tdeapplication.h>
#include <kdebug.h>
-#include <kfiledialog.h>
-#include <klocale.h>
+#include <tdefiledialog.h>
+#include <tdelocale.h>
#include <kiconloader.h>
-#include <kmessagebox.h>
+#include <tdemessagebox.h>
#include <kstandarddirs.h>
-#include <kaction.h>
-#include <kconfig.h>
+#include <tdeaction.h>
+#include <tdeconfig.h>
#include <kstdaction.h>
-#include <ktoolbar.h>
-#include <kpopupmenu.h>
+#include <tdetoolbar.h>
+#include <tdepopupmenu.h>
#include "setupdisplay.h"
PageSetupDialog::PageSetupDialog( TQWidget *parent, const Recipe &sample, const TQString &configEntry ) : KDialog( parent, 0, true ), m_configEntry(configEntry)
{
- KIconLoader il;
+ TDEIconLoader il;
TQVBoxLayout * layout = new TQVBoxLayout( this );
- KToolBar *toolbar = new KToolBar( this );
- KActionCollection *actionCollection = new KActionCollection( this );
+ TDEToolBar *toolbar = new TDEToolBar( this );
+ TDEActionCollection *actionCollection = new TDEActionCollection( this );
- KAction *std_open = KStdAction::open( 0, 0, 0 ); //use this to create a custom open action
- KToolBarPopupAction *custom_open = new KToolBarPopupAction( std_open->text(), std_open->icon(), std_open->shortcut(), this, SLOT( loadFile() ), actionCollection, "open_popup" );
+ TDEAction *std_open = KStdAction::open( 0, 0, 0 ); //use this to create a custom open action
+ TDEToolBarPopupAction *custom_open = new TDEToolBarPopupAction( std_open->text(), std_open->icon(), std_open->shortcut(), this, SLOT( loadFile() ), actionCollection, "open_popup" );
- KPopupMenu *open_popup = custom_open->popupMenu();
+ TDEPopupMenu *open_popup = custom_open->popupMenu();
open_popup->insertTitle( i18n( "Styles" ) );
TQDir included_layouts( getIncludedLayoutDir(), "*.klo", TQDir::Name | TQDir::IgnoreCase, TQDir::Files );
@@ -70,7 +70,7 @@ PageSetupDialog::PageSetupDialog( TQWidget *parent, const Recipe &sample, const
KStdAction::saveAs( this, SLOT( saveAsLayout() ), actionCollection ) ->plug( toolbar );
KStdAction::redisplay( this, SLOT( reloadLayout() ), actionCollection ) ->plug( toolbar );
- KToolBarPopupAction *shown_items = new KToolBarPopupAction( i18n( "Items Shown" ), "frame_edit" );
+ TDEToolBarPopupAction *shown_items = new TDEToolBarPopupAction( i18n( "Items Shown" ), "frame_edit" );
shown_items->setDelayed( false );
shown_items_popup = shown_items->popupMenu();
shown_items_popup->insertTitle( i18n( "Show Items" ) );
@@ -84,15 +84,15 @@ PageSetupDialog::PageSetupDialog( TQWidget *parent, const Recipe &sample, const
layout->addWidget( m_htmlPart->view() );
TQHBox *buttonsBox = new TQHBox( this );
- TQPushButton *okButton = new TQPushButton( il.loadIconSet( "ok", KIcon::Small ), i18n( "Save and Close" ), buttonsBox );
- TQPushButton *cancelButton = new TQPushButton( il.loadIconSet( "cancel", KIcon::Small ), i18n( "&Cancel" ), buttonsBox );
+ TQPushButton *okButton = new TQPushButton( il.loadIconSet( "ok", TDEIcon::Small ), i18n( "Save and Close" ), buttonsBox );
+ TQPushButton *cancelButton = new TQPushButton( il.loadIconSet( "cancel", TDEIcon::Small ), i18n( "&Cancel" ), buttonsBox );
layout->addWidget( buttonsBox );
connect( m_htmlPart, SIGNAL(itemVisibilityChanged(KreDisplayItem*,bool)), this, SLOT(updateItemVisibility(KreDisplayItem*,bool)) );
connect( okButton, SIGNAL( clicked() ), SLOT( accept() ) );
connect( cancelButton, SIGNAL( clicked() ), SLOT( reject() ) );
- KConfig *config = KGlobal::config();
+ TDEConfig *config = TDEGlobal::config();
config->setGroup( "Page Setup" );
TQSize defaultSize(300,400);
resize(config->readSizeEntry( "WindowSize", &defaultSize ));
@@ -118,18 +118,18 @@ void PageSetupDialog::accept()
saveLayout();
if ( !active_filename.isEmpty() ) {
- KConfig * config = kapp->config();
+ TDEConfig * config = kapp->config();
config->setGroup( "Page Setup" );
config->writeEntry( m_configEntry+"Layout", active_filename );
}
if ( !active_template.isEmpty() ) {
- KConfig * config = kapp->config();
+ TDEConfig * config = kapp->config();
config->setGroup( "Page Setup" );
config->writeEntry( m_configEntry+"Template", active_template );
}
- KConfig *config = kapp->config();
+ TDEConfig *config = kapp->config();
config->setGroup( "Page Setup" );
config->writeEntry( "WindowSize", size() );
@@ -259,7 +259,7 @@ void PageSetupDialog::saveLayout()
void PageSetupDialog::saveAsLayout()
{
- TQString filename = KFileDialog::getSaveFileName( KGlobal::instance() ->dirs() ->saveLocation( "appdata", "layouts/" ), "*.klo|Krecipes Layout (*.klo)", this, TQString::null );
+ TQString filename = KFileDialog::getSaveFileName( TDEGlobal::instance() ->dirs() ->saveLocation( "appdata", "layouts/" ), "*.klo|Krecipes Layout (*.klo)", this, TQString::null );
if ( !filename.isEmpty() ) {
if ( haveWritePerm( filename ) ) {
diff --git a/krecipes/src/dialogs/pagesetupdialog.h b/krecipes/src/dialogs/pagesetupdialog.h
index e125188..2ef48a5 100644
--- a/krecipes/src/dialogs/pagesetupdialog.h
+++ b/krecipes/src/dialogs/pagesetupdialog.h
@@ -17,7 +17,7 @@
#include "datablocks/recipe.h"
-class KPopupMenu;
+class TDEPopupMenu;
class SetupDisplay;
class KreDisplayItem;
@@ -66,7 +66,7 @@ private:
TQMap<int, KreDisplayItem*> popup_widget_map;
TQMap<KreDisplayItem*, int> widget_popup_map;
TQMap<int, TQString> included_layouts_map;
- KPopupMenu *shown_items_popup;
+ TDEPopupMenu *shown_items_popup;
};
#endif //PAGESETUPDIALOG_H
diff --git a/krecipes/src/dialogs/prepmethodsdialog.cpp b/krecipes/src/dialogs/prepmethodsdialog.cpp
index e74c1e5..1ec4b76 100644
--- a/krecipes/src/dialogs/prepmethodsdialog.cpp
+++ b/krecipes/src/dialogs/prepmethodsdialog.cpp
@@ -17,8 +17,8 @@
#include "widgets/prepmethodlistview.h"
#include <kdialog.h>
-#include <klocale.h>
-#include <kmessagebox.h>
+#include <tdelocale.h>
+#include <tdemessagebox.h>
PrepMethodsDialog::PrepMethodsDialog( TQWidget* parent, RecipeDB *db ) : TQWidget( parent )
{
diff --git a/krecipes/src/dialogs/prepmethodsdialog.h b/krecipes/src/dialogs/prepmethodsdialog.h
index 9b684e7..542d514 100644
--- a/krecipes/src/dialogs/prepmethodsdialog.h
+++ b/krecipes/src/dialogs/prepmethodsdialog.h
@@ -18,7 +18,7 @@
#include <ntqhbox.h>
#include <ntqlayout.h>
#include <kiconloader.h>
-#include <klistview.h>
+#include <tdelistview.h>
#include "widgets/dblistviewbase.h"
@@ -48,6 +48,6 @@ private:
TQHBox *buttonBar;
TQPushButton *newPrepMethodButton;
TQPushButton *removePrepMethodButton;
- KIconLoader *il;
+ TDEIconLoader *il;
};
#endif
diff --git a/krecipes/src/dialogs/propertiesdialog.cpp b/krecipes/src/dialogs/propertiesdialog.cpp
index 8f5bcbd..f1b4d48 100644
--- a/krecipes/src/dialogs/propertiesdialog.cpp
+++ b/krecipes/src/dialogs/propertiesdialog.cpp
@@ -11,10 +11,10 @@
***************************************************************************/
#include "propertiesdialog.h"
-#include <klocale.h>
+#include <tdelocale.h>
#include <kdialog.h>
-#include <kmessagebox.h>
-#include <kconfig.h>
+#include <tdemessagebox.h>
+#include <tdeconfig.h>
#include "backends/recipedb.h"
#include "createpropertydialog.h"
@@ -33,7 +33,7 @@ PropertiesDialog::PropertiesDialog( TQWidget *parent, RecipeDB *db ) : TQWidget(
propertyListView = new CheckPropertyListView( this, database, true );
propertyListView->reload();
- KConfig *config = KGlobal::config();
+ TDEConfig *config = TDEGlobal::config();
config->setGroup("Formatting");
TQStringList hiddenList = config->readListEntry("HiddenProperties");
for ( TQCheckListItem *item = (TQCheckListItem*)propertyListView->firstChild(); item; item = (TQCheckListItem*)item->nextSibling() ) {
diff --git a/krecipes/src/dialogs/propertiesdialog.h b/krecipes/src/dialogs/propertiesdialog.h
index 77638d3..58437fd 100644
--- a/krecipes/src/dialogs/propertiesdialog.h
+++ b/krecipes/src/dialogs/propertiesdialog.h
@@ -16,7 +16,7 @@
#include <ntqlayout.h>
#include <ntqpushbutton.h>
#include <ntqvbox.h>
-#include <klistview.h>
+#include <tdelistview.h>
class RecipeDB;
class StdPropertyListView;
diff --git a/krecipes/src/dialogs/recipeimportdialog.cpp b/krecipes/src/dialogs/recipeimportdialog.cpp
index 40e8448..1b9671d 100644
--- a/krecipes/src/dialogs/recipeimportdialog.cpp
+++ b/krecipes/src/dialogs/recipeimportdialog.cpp
@@ -12,9 +12,9 @@
#include "recipeimportdialog.h"
-#include <klocale.h>
+#include <tdelocale.h>
#include <kpushbutton.h>
-#include <klistview.h>
+#include <tdelistview.h>
#include <kdebug.h>
#include <ntqvbox.h>
@@ -34,7 +34,7 @@ RecipeImportDialog::RecipeImportDialog( const RecipeList &list, TQWidget *parent
TQVBox *page = makeVBoxMainWidget();
- kListView = new KListView( page );
+ kListView = new TDEListView( page );
kListView->addColumn( i18n( "Recipes" ) );
kListView->setProperty( "selectionMode", "NoSelection" );
kListView->setRootIsDecorated( true );
diff --git a/krecipes/src/dialogs/recipeimportdialog.h b/krecipes/src/dialogs/recipeimportdialog.h
index 7339c65..98768ea 100644
--- a/krecipes/src/dialogs/recipeimportdialog.h
+++ b/krecipes/src/dialogs/recipeimportdialog.h
@@ -21,7 +21,7 @@
#include "datablocks/recipelist.h"
-class KListView;
+class TDEListView;
class TQListViewItem;
@@ -45,7 +45,7 @@ protected slots:
private:
void loadListView();
- KListView* kListView;
+ TDEListView* kListView;
TQMap<CustomCheckListItem*, RecipeList::const_iterator> *recipe_items;
const RecipeList list_copy;
diff --git a/krecipes/src/dialogs/recipeinputdialog.cpp b/krecipes/src/dialogs/recipeinputdialog.cpp
index 76a0c82..455b75f 100644
--- a/krecipes/src/dialogs/recipeinputdialog.cpp
+++ b/krecipes/src/dialogs/recipeinputdialog.cpp
@@ -28,13 +28,13 @@
#include <ntqwidgetstack.h>
#include <ntqpainter.h>
-#include <kapplication.h>
-#include <kcompletionbox.h>
-#include <kspell.h>
+#include <tdeapplication.h>
+#include <tdecompletionbox.h>
+#include <tdespell.h>
#include <kurl.h>
-#include <kfiledialog.h>
-#include <klocale.h>
-#include <kmessagebox.h>
+#include <tdefiledialog.h>
+#include <tdelocale.h>
+#include <tdemessagebox.h>
#include <kdebug.h>
#include <kled.h>
#include <kdialogbase.h>
@@ -114,7 +114,7 @@ RecipeInputDialog::RecipeInputDialog( TQWidget* parent, RecipeDB *db ) : TQVBox(
loadedRecipe->instructions = TQString::null;
database = db;
- KIconLoader *il = new KIconLoader;
+ TDEIconLoader *il = new TDEIconLoader;
// Tabs
tabWidget = new TQTabWidget( this, "tabWidget" );
@@ -161,7 +161,7 @@ RecipeInputDialog::RecipeInputDialog( TQWidget* parent, RecipeDB *db ) : TQVBox(
( changePhotoButton, i18n( "Select photo" ) );
TQPushButton *clearPhotoButton = new TQPushButton( photoButtonsBox );
- clearPhotoButton->setPixmap( il->loadIcon( "clear_left", KIcon::NoGroup, 16 ) );
+ clearPhotoButton->setPixmap( il->loadIcon( "clear_left", TDEIcon::NoGroup, 16 ) );
TQToolTip::add
( clearPhotoButton, i18n( "Clear photo" ) );
@@ -288,7 +288,7 @@ RecipeInputDialog::RecipeInputDialog( TQWidget* parent, RecipeDB *db ) : TQVBox(
addButton = new KPushButton( ingredientGBox );
addButton->setFixedSize( TQSize( 31, 31 ) );
addButton->setFlat( true );
- TQPixmap pm = il->loadIcon( "new", KIcon::NoGroup, 16 );
+ TQPixmap pm = il->loadIcon( "new", TDEIcon::NoGroup, 16 );
addButton->setPixmap( pm );
addButton->setSizePolicy( TQSizePolicy( TQSizePolicy::Fixed, TQSizePolicy::Fixed ) );
ingredientsLayout->addWidget( addButton, 3, 5 );
@@ -300,7 +300,7 @@ RecipeInputDialog::RecipeInputDialog( TQWidget* parent, RecipeDB *db ) : TQVBox(
upButton = new KPushButton( ingredientGBox );
upButton->setFixedSize( TQSize( 31, 31 ) );
upButton->setFlat( true );
- pm = il->loadIcon( "up", KIcon::NoGroup, 16 );
+ pm = il->loadIcon( "up", TDEIcon::NoGroup, 16 );
upButton->setPixmap( pm );
upButton->setSizePolicy( TQSizePolicy( TQSizePolicy::Fixed, TQSizePolicy::Fixed ) );
ingredientsLayout->addWidget( upButton, 5, 5 );
@@ -308,7 +308,7 @@ RecipeInputDialog::RecipeInputDialog( TQWidget* parent, RecipeDB *db ) : TQVBox(
downButton = new KPushButton( ingredientGBox );
downButton->setFixedSize( TQSize( 31, 31 ) );
downButton->setFlat( true );
- pm = il->loadIcon( "down", KIcon::NoGroup, 16 );
+ pm = il->loadIcon( "down", TDEIcon::NoGroup, 16 );
downButton->setPixmap( pm );
downButton->setSizePolicy( TQSizePolicy( TQSizePolicy::Fixed, TQSizePolicy::Fixed ) );
ingredientsLayout->addWidget( downButton, 6, 5 );
@@ -316,7 +316,7 @@ RecipeInputDialog::RecipeInputDialog( TQWidget* parent, RecipeDB *db ) : TQVBox(
removeButton = new KPushButton( ingredientGBox );
removeButton->setFixedSize( TQSize( 31, 31 ) );
removeButton->setFlat( true );
- pm = il->loadIcon( "remove", KIcon::NoGroup, 16 );
+ pm = il->loadIcon( "remove", TDEIcon::NoGroup, 16 );
removeButton->setPixmap( pm );
removeButton->setSizePolicy( TQSizePolicy( TQSizePolicy::Fixed, TQSizePolicy::Fixed ) );
ingredientsLayout->addWidget( removeButton, 7, 5 );
@@ -324,7 +324,7 @@ RecipeInputDialog::RecipeInputDialog( TQWidget* parent, RecipeDB *db ) : TQVBox(
ingParserButton = new KPushButton( ingredientGBox );
ingParserButton->setFixedSize( TQSize( 31, 31 ) );
ingParserButton->setFlat( true );
- pm = il->loadIcon( "editpaste", KIcon::NoGroup, 16 );
+ pm = il->loadIcon( "editpaste", TDEIcon::NoGroup, 16 );
ingParserButton->setPixmap( pm );
ingParserButton->setSizePolicy( TQSizePolicy( TQSizePolicy::Fixed, TQSizePolicy::Fixed ) );
ingredientsLayout->addWidget( ingParserButton, 8, 5 );
@@ -341,7 +341,7 @@ RecipeInputDialog::RecipeInputDialog( TQWidget* parent, RecipeDB *db ) : TQVBox(
( ingParserButton, i18n( "Paste Ingredients" ) );
// Ingredient List
- ingredientList = new KListView( ingredientGBox, "ingredientList" );
+ ingredientList = new TDEListView( ingredientGBox, "ingredientList" );
ingredientList->addColumn( i18n( "Ingredient" ) );
ingredientList->addColumn( i18n( "Amount" ) );
ingredientList->setColumnAlignment( 1, TQt::AlignHCenter );
@@ -374,7 +374,7 @@ RecipeInputDialog::RecipeInputDialog( TQWidget* parent, RecipeDB *db ) : TQVBox(
KGuiItem updateGuiItem;
updateGuiItem.setText( i18n("Update") );
- updateGuiItem.setIconSet( il->loadIconSet( "reload", KIcon::NoGroup ) );
+ updateGuiItem.setIconSet( il->loadIconSet( "reload", TDEIcon::NoGroup ) );
propertyStatusDialog = new KDialogBase( KDialogBase::Swallow, i18n("Property details"),
KDialogBase::Close | KDialogBase::User1 | KDialogBase::Help,
KDialogBase::Close, this, "propertyStatusDialog", false, false,
@@ -403,7 +403,7 @@ RecipeInputDialog::RecipeInputDialog( TQWidget* parent, RecipeDB *db ) : TQVBox(
instructionsLayout->addWidget( instructionsEdit );
spellCheckButton = new TQToolButton( instructionsTab );
- spellCheckButton->setIconSet( il->loadIconSet( "spellcheck", KIcon::Small ) );
+ spellCheckButton->setIconSet( il->loadIconSet( "spellcheck", TDEIcon::Small ) );
TQToolTip::add
( spellCheckButton, i18n( "Check spelling" ) );
instructionsLayout->addWidget( spellCheckButton );
@@ -435,14 +435,14 @@ RecipeInputDialog::RecipeInputDialog( TQWidget* parent, RecipeDB *db ) : TQVBox(
functionsBox->setFrameStyle( TQFrame::NoFrame );
saveButton = new TQToolButton( functionsBox );
- saveButton->setIconSet( il->loadIconSet( "filesave", KIcon::Small ) );
+ saveButton->setIconSet( il->loadIconSet( "filesave", TDEIcon::Small ) );
saveButton->setEnabled( false );
showButton = new TQToolButton( functionsBox );
- showButton->setIconSet( il->loadIconSet( "viewmag", KIcon::Small ) );
+ showButton->setIconSet( il->loadIconSet( "viewmag", TDEIcon::Small ) );
closeButton = new TQToolButton( functionsBox );
- closeButton->setIconSet( il->loadIconSet( "fileclose", KIcon::Small ) );
+ closeButton->setIconSet( il->loadIconSet( "fileclose", TDEIcon::Small ) );
resizeButton = new TQToolButton( functionsBox );
- resizeButton->setIconSet( il->loadIconSet( "2uparrow", KIcon::Small ) ); //TODO: give me an icon :)
+ resizeButton->setIconSet( il->loadIconSet( "2uparrow", TDEIcon::Small ) ); //TODO: give me an icon :)
saveButton->setTextLabel( i18n( "Save recipe" ), true );
saveButton->setUsesTextLabel( true );
@@ -656,7 +656,7 @@ void RecipeInputDialog::reload( void )
ratingListDisplayWidget->ensureCellVisible(0,0);
// Update yield type auto completion
- KCompletion *completion = yieldTypeEdit->completionObject();
+ TDECompletion *completion = yieldTypeEdit->completionObject();
completion->clear();
ElementList yieldList;
database->loadYieldTypes( &yieldList );
diff --git a/krecipes/src/dialogs/recipeinputdialog.h b/krecipes/src/dialogs/recipeinputdialog.h
index 085f0d3..12c49c3 100644
--- a/krecipes/src/dialogs/recipeinputdialog.h
+++ b/krecipes/src/dialogs/recipeinputdialog.h
@@ -17,7 +17,7 @@
#include <ktextedit.h>
#include <klineedit.h>
#include <kcombobox.h>
-#include <klistview.h>
+#include <tdelistview.h>
#include <knuminput.h>
#include <kpushbutton.h>
#include <kiconloader.h>
@@ -108,7 +108,7 @@ private:
TQPushButton* addCategoryButton;
//Ingredient inputs
- KListView* ingredientList;
+ TDEListView* ingredientList;
TQGroupBox *ingredientGBox;
IngredientInputWidget *ingInput;
ClickableLed *propertyStatusLed;
diff --git a/krecipes/src/dialogs/recipeprintpreview.cpp b/krecipes/src/dialogs/recipeprintpreview.cpp
index 8a7a96f..c2019e3 100644
--- a/krecipes/src/dialogs/recipeprintpreview.cpp
+++ b/krecipes/src/dialogs/recipeprintpreview.cpp
@@ -13,7 +13,7 @@
#include <ntqvbox.h>
#include <kdebug.h>
-#include <klocale.h>
+#include <tdelocale.h>
#include "recipeviewdialog.h"
#include "pagesetupdialog.h"
diff --git a/krecipes/src/dialogs/recipeviewdialog.h b/krecipes/src/dialogs/recipeviewdialog.h
index 0463a1e..17ce110 100644
--- a/krecipes/src/dialogs/recipeviewdialog.h
+++ b/krecipes/src/dialogs/recipeviewdialog.h
@@ -18,7 +18,7 @@
class RecipeDB;
class Recipe;
-class KHTMLPart;
+class TDEHTMLPart;
class TQPushButton;
/**
@@ -58,7 +58,7 @@ public slots:
private:
// Internal Variables
- KHTMLPart *recipeView;
+ TDEHTMLPart *recipeView;
RecipeDB *database;
bool recipe_loaded;
TQValueList<int> ids_loaded;
diff --git a/krecipes/src/dialogs/refineshoppinglistdialog.cpp b/krecipes/src/dialogs/refineshoppinglistdialog.cpp
index e160c2e..b3ad2c2 100644
--- a/krecipes/src/dialogs/refineshoppinglistdialog.cpp
+++ b/krecipes/src/dialogs/refineshoppinglistdialog.cpp
@@ -18,11 +18,11 @@
#include <ntqtooltip.h>
#include <ntqwhatsthis.h>
-#include <klocale.h>
+#include <tdelocale.h>
#include <kiconloader.h>
-#include <kapplication.h>
+#include <tdeapplication.h>
#include <kcursor.h>
-#include <kconfig.h>
+#include <tdeconfig.h>
#include "backends/recipedb.h"
#include "widgets/krelistview.h"
@@ -55,15 +55,15 @@ RefineShoppingListDialog::RefineShoppingListDialog( TQWidget* parent, RecipeDB *
layout1 = new TQVBoxLayout( 0, 0, 6, "layout1" );
- KIconLoader il;
+ TDEIconLoader il;
addButton = new TQPushButton( layout2Widget, "addButton" );
- addButton->setIconSet( il.loadIconSet( "forward", KIcon::Small ) );
+ addButton->setIconSet( il.loadIconSet( "forward", TDEIcon::Small ) );
addButton->setFixedSize( TQSize( 32, 32 ) );
layout1->addWidget( addButton );
removeButton = new TQPushButton( layout2Widget, "removeButton" );
- removeButton->setIconSet( il.loadIconSet( "back", KIcon::Small ) );
+ removeButton->setIconSet( il.loadIconSet( "back", TDEIcon::Small ) );
removeButton->setFixedSize( TQSize( 32, 32 ) );
layout1->addWidget( removeButton );
spacer1 = new TQSpacerItem( 51, 191, TQSizePolicy::Minimum, TQSizePolicy::Expanding );
@@ -88,9 +88,9 @@ RefineShoppingListDialog::RefineShoppingListDialog( TQWidget* parent, RecipeDB *
connect( removeButton, SIGNAL( clicked() ), this, SLOT( removeIngredient() ) );
connect( ingListView->listView(), SIGNAL( itemRenamed( TQListViewItem*, const TQString &, int ) ), SLOT( itemRenamed( TQListViewItem*, const TQString &, int ) ) );
- KApplication::setOverrideCursor( KCursor::waitCursor() );
+ TDEApplication::setOverrideCursor( KCursor::waitCursor() );
calculateShopping( recipeList, &ingredientList, database );
- KApplication::restoreOverrideCursor();
+ TDEApplication::restoreOverrideCursor();
loadData();
}
@@ -126,13 +126,13 @@ void RefineShoppingListDialog::loadData()
TQString amount_str;
if ( ( *it ).amount > 0 ) {
- KConfig * config = kapp->config();
+ TDEConfig * config = kapp->config();
config->setGroup( "Formatting" );
if ( config->readBoolEntry( "Fraction" ) )
amount_str = MixedNumber( ( *it ).amount ).toString();
else
- amount_str = beautify( KGlobal::locale() ->formatNumber( ( *it ).amount, 5 ) );
+ amount_str = beautify( TDEGlobal::locale() ->formatNumber( ( *it ).amount, 5 ) );
}
TQListViewItem *new_item = new TQListViewItem( ingListView->listView(), ( *it ).name, amount_str, ( *it ).amount > 1 ? ( *it ).units.plural : ( *it ).units.name );
@@ -181,13 +181,13 @@ void RefineShoppingListDialog::itemRenamed( TQListViewItem* item, const TQString
else { //revert back to the valid amount string
TQString amount_str;
if ( ( *found_it ).amount > 0 ) {
- KConfig * config = kapp->config();
+ TDEConfig * config = kapp->config();
config->setGroup( "Formatting" );
if ( config->readBoolEntry( "Fraction" ) )
amount_str = MixedNumber( ( *found_it ).amount ).toString();
else
- amount_str = beautify( KGlobal::locale() ->formatNumber( ( *found_it ).amount, 5 ) );
+ amount_str = beautify( TDEGlobal::locale() ->formatNumber( ( *found_it ).amount, 5 ) );
}
item->setText( 1, amount_str );
diff --git a/krecipes/src/dialogs/resizerecipedialog.cpp b/krecipes/src/dialogs/resizerecipedialog.cpp
index 3b3ef34..71cc3c9 100644
--- a/krecipes/src/dialogs/resizerecipedialog.cpp
+++ b/krecipes/src/dialogs/resizerecipedialog.cpp
@@ -28,8 +28,8 @@
#include <ntqimage.h>
#include <ntqpixmap.h>
-#include <klocale.h>
-#include <kmessagebox.h>
+#include <tdelocale.h>
+#include <tdemessagebox.h>
#include <kdebug.h>
#include "datablocks/recipe.h"
diff --git a/krecipes/src/dialogs/selectauthorsdialog.cpp b/krecipes/src/dialogs/selectauthorsdialog.cpp
index d400aef..dc6be76 100644
--- a/krecipes/src/dialogs/selectauthorsdialog.cpp
+++ b/krecipes/src/dialogs/selectauthorsdialog.cpp
@@ -15,11 +15,11 @@
#include <ntqmessagebox.h>
#include <ntqvbox.h>
-#include <kconfig.h>
+#include <tdeconfig.h>
#include <kdialog.h>
-#include <klocale.h>
-#include <kmessagebox.h>
-#include <kglobal.h>
+#include <tdelocale.h>
+#include <tdemessagebox.h>
+#include <tdeglobal.h>
#include "backends/recipedb.h"
@@ -38,26 +38,26 @@ SelectAuthorsDialog::SelectAuthorsDialog( TQWidget *parent, const ElementList &c
authorsCombo = new KComboBox( true, topBox );
authorsCombo->setSizePolicy( TQSizePolicy( TQSizePolicy::MinimumExpanding, TQSizePolicy::MinimumExpanding ) );
- authorsCombo->completionObject() ->setCompletionMode( KGlobalSettings::CompletionPopupAuto );
+ authorsCombo->completionObject() ->setCompletionMode( TDEGlobalSettings::CompletionPopupAuto );
authorsCombo->lineEdit() ->disconnect( authorsCombo ); //so hitting enter doesn't enter the item into the box
// Add/Remove buttons
- il = new KIconLoader;
+ il = new TDEIconLoader;
addAuthorButton = new TQPushButton( topBox );
- TQPixmap pm = il->loadIcon( "down", KIcon::NoGroup, 16 );
+ TQPixmap pm = il->loadIcon( "down", TDEIcon::NoGroup, 16 );
addAuthorButton->setIconSet( pm );
removeAuthorButton = new TQPushButton( topBox );
- pm = il->loadIcon( "up", KIcon::NoGroup, 16 );
+ pm = il->loadIcon( "up", TDEIcon::NoGroup, 16 );
removeAuthorButton->setIconSet( pm );
// Author List
- authorListView = new KListView( page );
+ authorListView = new TDEListView( page );
authorListView->setSizePolicy( TQSizePolicy( TQSizePolicy::MinimumExpanding, TQSizePolicy::MinimumExpanding ) );
- KConfig * config = KGlobal::config();
+ TDEConfig * config = TDEGlobal::config();
config->setGroup( "Advanced" );
bool show_id = config->readBoolEntry( "ShowID", false );
authorListView->addColumn( i18n( "Id" ), show_id ? -1 : 0 );
diff --git a/krecipes/src/dialogs/selectauthorsdialog.h b/krecipes/src/dialogs/selectauthorsdialog.h
index c555a17..4e550f3 100644
--- a/krecipes/src/dialogs/selectauthorsdialog.h
+++ b/krecipes/src/dialogs/selectauthorsdialog.h
@@ -18,7 +18,7 @@
#include <kdialogbase.h>
#include <kiconloader.h>
-#include <klistview.h>
+#include <tdelistview.h>
#include <kcombobox.h>
#include "datablocks/elementlist.h"
@@ -43,12 +43,12 @@ private:
//Widgets
KComboBox *authorsCombo;
- KListView *authorListView;
+ TDEListView *authorListView;
TQPushButton *okButton;
TQPushButton *cancelButton;
TQPushButton *addAuthorButton;
TQPushButton *removeAuthorButton;
- KIconLoader *il;
+ TDEIconLoader *il;
//Variables
ElementList authorList;
diff --git a/krecipes/src/dialogs/selectcategoriesdialog.cpp b/krecipes/src/dialogs/selectcategoriesdialog.cpp
index 6674182..8e156d9 100644
--- a/krecipes/src/dialogs/selectcategoriesdialog.cpp
+++ b/krecipes/src/dialogs/selectcategoriesdialog.cpp
@@ -15,10 +15,10 @@
#include <ntqvbox.h>
-#include <klocale.h>
+#include <tdelocale.h>
#include <kdebug.h>
#include <kdialog.h>
-#include <kmessagebox.h>
+#include <tdemessagebox.h>
#include "datablocks/categorytree.h"
#include "backends/recipedb.h"
diff --git a/krecipes/src/dialogs/selectcategoriesdialog.h b/krecipes/src/dialogs/selectcategoriesdialog.h
index f65ad1f..15f2d6a 100644
--- a/krecipes/src/dialogs/selectcategoriesdialog.h
+++ b/krecipes/src/dialogs/selectcategoriesdialog.h
@@ -16,7 +16,7 @@
#include <ntqlayout.h>
#include <ntqpushbutton.h>
-#include <klistview.h>
+#include <tdelistview.h>
#include <kdialogbase.h>
#include "datablocks/elementlist.h"
diff --git a/krecipes/src/dialogs/selectpropertydialog.cpp b/krecipes/src/dialogs/selectpropertydialog.cpp
index 8b46d12..1ce1887 100644
--- a/krecipes/src/dialogs/selectpropertydialog.cpp
+++ b/krecipes/src/dialogs/selectpropertydialog.cpp
@@ -12,9 +12,9 @@
#include "selectpropertydialog.h"
-#include <kconfig.h>
-#include <kglobal.h>
-#include <klocale.h>
+#include <tdeconfig.h>
+#include <tdeglobal.h>
+#include <tdelocale.h>
#include "datablocks/ingredientpropertylist.h"
@@ -37,9 +37,9 @@ SelectPropertyDialog::SelectPropertyDialog( TQWidget* parent, IngredientProperty
TQVBoxLayout *boxLayout = new TQVBoxLayout( box->layout() );
boxLayout->setAlignment( TQt::AlignTop );
- propertyChooseView = new KListView( box, "propertyChooseView" );
+ propertyChooseView = new TDEListView( box, "propertyChooseView" );
- KConfig *config = KGlobal::config();
+ TDEConfig *config = TDEGlobal::config();
config->setGroup( "Advanced" );
bool show_id = config->readBoolEntry( "ShowID", false );
propertyChooseView->addColumn( i18n( "Id" ), show_id ? -1 : 0 );
diff --git a/krecipes/src/dialogs/selectpropertydialog.h b/krecipes/src/dialogs/selectpropertydialog.h
index 1b6fa7c..9aec6ff 100644
--- a/krecipes/src/dialogs/selectpropertydialog.h
+++ b/krecipes/src/dialogs/selectpropertydialog.h
@@ -20,7 +20,7 @@
#include <ntqpushbutton.h>
#include <ntqvbox.h>
-#include <klistview.h>
+#include <tdelistview.h>
#include <kcombobox.h>
#include <kdialogbase.h>
@@ -44,7 +44,7 @@ public:
private:
//Widgets
TQGroupBox *box;
- KListView *propertyChooseView;
+ TDEListView *propertyChooseView;
TQLabel *perUnitsLabel;
KComboBox *perUnitsBox;
OptionFlag m_showEmpty;
diff --git a/krecipes/src/dialogs/selectrecipedialog.cpp b/krecipes/src/dialogs/selectrecipedialog.cpp
index b738c3b..0b63d04 100644
--- a/krecipes/src/dialogs/selectrecipedialog.cpp
+++ b/krecipes/src/dialogs/selectrecipedialog.cpp
@@ -16,13 +16,13 @@
#include <ntqtabwidget.h>
#include <ntqtooltip.h>
-#include <klocale.h>
+#include <tdelocale.h>
#include <kdebug.h>
-#include <kapplication.h>
+#include <tdeapplication.h>
#include <kprogress.h>
-#include <kmessagebox.h>
-#include <kglobal.h>
-#include <kconfig.h>
+#include <tdemessagebox.h>
+#include <tdeglobal.h>
+#include <tdeconfig.h>
#include <kcursor.h>
#include <kiconloader.h>
@@ -66,9 +66,9 @@ SelectRecipeDialog::SelectRecipeDialog( TQWidget *parent, RecipeDB* db )
searchBar->setSpacing( 7 );
layout->addWidget( searchBar, 1, 1 );
- KIconLoader *il = new KIconLoader;
+ TDEIconLoader *il = new TDEIconLoader;
TQPushButton *clearSearchButton = new TQPushButton( searchBar );
- clearSearchButton->setPixmap( il->loadIcon( "locationbar_erase", KIcon::NoGroup, 16 ) );
+ clearSearchButton->setPixmap( il->loadIcon( "locationbar_erase", TDEIcon::NoGroup, 16 ) );
searchLabel = new TQLabel( searchBar );
searchLabel->setText( i18n( "Search:" ) );
@@ -97,18 +97,18 @@ SelectRecipeDialog::SelectRecipeDialog( TQWidget *parent, RecipeDB* db )
openButton = new TQPushButton( buttonBar );
openButton->setText( i18n( "Open Recipe(s)" ) );
openButton->setDisabled( true );
- TQPixmap pm = il->loadIcon( "ok", KIcon::NoGroup, 16 );
+ TQPixmap pm = il->loadIcon( "ok", TDEIcon::NoGroup, 16 );
openButton->setIconSet( pm );
editButton = new TQPushButton( buttonBar );
editButton->setText( i18n( "Edit Recipe" ) );
editButton->setDisabled( true );
- pm = il->loadIcon( "edit", KIcon::NoGroup, 16 );
+ pm = il->loadIcon( "edit", TDEIcon::NoGroup, 16 );
editButton->setIconSet( pm );
removeButton = new TQPushButton( buttonBar );
removeButton->setText( i18n( "Delete" ) );
removeButton->setDisabled( true );
removeButton->setMaximumWidth( 100 );
- pm = il->loadIcon( "editshred", KIcon::NoGroup, 16 );
+ pm = il->loadIcon( "editshred", TDEIcon::NoGroup, 16 );
removeButton->setIconSet( pm );
tabWidget->insertTab( basicSearchTab, i18n( "Basic" ) );
@@ -134,7 +134,7 @@ SelectRecipeDialog::SelectRecipeDialog( TQWidget *parent, RecipeDB* db )
connect( clearSearchButton, SIGNAL( clicked() ), this, SLOT( clearSearch() ) );
- KConfig * config = kapp->config();
+ TDEConfig * config = kapp->config();
config->setGroup( "Performance" );
if ( config->readBoolEntry("SearchAsYouType",true) ) {
connect( searchBox, SIGNAL( returnPressed( const TQString& ) ), recipeFilter, SLOT( filter( const TQString& ) ) );
diff --git a/krecipes/src/dialogs/selectrecipedialog.h b/krecipes/src/dialogs/selectrecipedialog.h
index e9ea0f6..f58dbd3 100644
--- a/krecipes/src/dialogs/selectrecipedialog.h
+++ b/krecipes/src/dialogs/selectrecipedialog.h
@@ -23,10 +23,10 @@
#include <kcombobox.h>
#include <klineedit.h>
-#include <klistview.h>
+#include <tdelistview.h>
#include <kdialog.h>
-#include <kfiledialog.h>
-#include <kpopupmenu.h>
+#include <tdefiledialog.h>
+#include <tdepopupmenu.h>
#include "recipeactionshandler.h"
#include "widgets/dblistviewbase.h"
diff --git a/krecipes/src/dialogs/selectunitdialog.cpp b/krecipes/src/dialogs/selectunitdialog.cpp
index 2478fc1..d9500a6 100644
--- a/krecipes/src/dialogs/selectunitdialog.cpp
+++ b/krecipes/src/dialogs/selectunitdialog.cpp
@@ -12,9 +12,9 @@
#include "selectunitdialog.h"
-#include <kconfig.h>
-#include <kglobal.h>
-#include <klocale.h>
+#include <tdeconfig.h>
+#include <tdeglobal.h>
+#include <tdelocale.h>
SelectUnitDialog::SelectUnitDialog( TQWidget* parent, const UnitList &unitList, OptionFlag showEmpty )
: KDialogBase( parent, "SelectUnitDialog", true, i18n( "Choose Unit" ),
@@ -27,9 +27,9 @@ SelectUnitDialog::SelectUnitDialog( TQWidget* parent, const UnitList &unitList,
box->setColumnLayout( 0, TQt::Vertical );
TQVBoxLayout *boxLayout = new TQVBoxLayout( box->layout() );
- unitChooseView = new KListView( box );
+ unitChooseView = new TDEListView( box );
- KConfig *config = KGlobal::config();
+ TDEConfig *config = TDEGlobal::config();
config->setGroup( "Advanced" );
bool show_id = config->readBoolEntry( "ShowID", false );
unitChooseView->addColumn( i18n( "Id" ), show_id ? -1 : 0 );
diff --git a/krecipes/src/dialogs/selectunitdialog.h b/krecipes/src/dialogs/selectunitdialog.h
index 03b4762..8e7e7ca 100644
--- a/krecipes/src/dialogs/selectunitdialog.h
+++ b/krecipes/src/dialogs/selectunitdialog.h
@@ -19,7 +19,7 @@
#include <ntqgroupbox.h>
#include <ntqvbox.h>
-#include <klistview.h>
+#include <tdelistview.h>
#include <kdialogbase.h>
#include "datablocks/unit.h"
@@ -41,7 +41,7 @@ public:
private:
//Widgets
TQGroupBox *box;
- KListView *unitChooseView;
+ TDEListView *unitChooseView;
OptionFlag m_showEmpty;
void loadUnits( const UnitList &unitList );
diff --git a/krecipes/src/dialogs/setupdisplay.cpp b/krecipes/src/dialogs/setupdisplay.cpp
index 1b1db6a..cf36f61 100644
--- a/krecipes/src/dialogs/setupdisplay.cpp
+++ b/krecipes/src/dialogs/setupdisplay.cpp
@@ -10,18 +10,18 @@
#include "setupdisplay.h"
-#include <kapplication.h>
-#include <kconfig.h>
+#include <tdeapplication.h>
+#include <tdeconfig.h>
#include <kdebug.h>
-#include <kfontdialog.h>
+#include <tdefontdialog.h>
#include <kcolordialog.h>
-#include <klocale.h>
-#include <kpopupmenu.h>
+#include <tdelocale.h>
+#include <tdepopupmenu.h>
#include <kiconloader.h>
#include <kstandarddirs.h>
-#include <ktempfile.h>
+#include <tdetempfile.h>
-#include <khtmlview.h>
+#include <tdehtmlview.h>
#include <dom/dom_doc.h>
#include <dom/css_rule.h>
@@ -56,7 +56,7 @@ void KreDisplayItem::clear()
columns = 1;
}
-SetupDisplay::SetupDisplay( const Recipe &sample, TQWidget *parent ) : KHTMLPart(parent),
+SetupDisplay::SetupDisplay( const Recipe &sample, TQWidget *parent ) : TDEHTMLPart(parent),
box_properties( new PropertiesMap ),
node_item_map( new TQMap<TQString, KreDisplayItem*> ),
has_changes( false ),
@@ -360,7 +360,7 @@ void SetupDisplay::saveLayout( const TQString &filename )
void SetupDisplay::begin(const KURL &url, int xOffset, int yOffset)
{
kdDebug()<<"begin"<<endl;
- KHTMLPart::begin(url,xOffset,yOffset);
+ TDEHTMLPart::begin(url,xOffset,yOffset);
kdDebug()<<"end"<<endl;
DOM::Document doc = document();
@@ -406,7 +406,7 @@ void SetupDisplay::nodeClicked(const TQString &/*url*/,const TQPoint &point)
KreDisplayItem *item = *node_item_map->find( m_currNodeId );
delete popup;
- popup = new KPopupMenu( view() );
+ popup = new TDEPopupMenu( view() );
popup->insertTitle( item->name );
unsigned int properties = 0;
@@ -417,7 +417,7 @@ void SetupDisplay::nodeClicked(const TQString &/*url*/,const TQPoint &point)
}
}
- KIconLoader il;
+ TDEIconLoader il;
if ( properties & BackgroundColor )
popup->insertItem( i18n( "Background Color..." ), this, SLOT( setBackgroundColor() ) );
@@ -426,7 +426,7 @@ void SetupDisplay::nodeClicked(const TQString &/*url*/,const TQPoint &point)
popup->insertItem( i18n( "Text Color..." ), this, SLOT( setTextColor() ) );
if ( properties & Font )
- popup->insertItem( il.loadIconSet( "text", KIcon::Small, 16 ), i18n( "Font..." ), this, SLOT( setFont() ) );
+ popup->insertItem( il.loadIconSet( "text", TDEIcon::Small, 16 ), i18n( "Font..." ), this, SLOT( setFont() ) );
if ( properties & Visibility ) {
int id = popup->insertItem( i18n( "Show" ), this, SLOT( setShown( int ) ) );
@@ -546,7 +546,7 @@ void SetupDisplay::setShown( int id )
void SetupDisplay::setFont()
{
KreDisplayItem *item = *node_item_map->find( m_currNodeId );
- if ( KFontDialog::getFont( item->font, false, view() ) == TQDialog::Accepted ) {
+ if ( TDEFontDialog::getFont( item->font, false, view() ) == TQDialog::Accepted ) {
m_currentItem = item;
loadFont(m_currNodeId,item->font);
m_currentItem = 0;
diff --git a/krecipes/src/dialogs/shoppinglistdialog.cpp b/krecipes/src/dialogs/shoppinglistdialog.cpp
index f0ebc85..87848a7 100644
--- a/krecipes/src/dialogs/shoppinglistdialog.cpp
+++ b/krecipes/src/dialogs/shoppinglistdialog.cpp
@@ -12,12 +12,12 @@
#include "shoppinglistdialog.h"
-#include <klocale.h>
-#include <kconfig.h>
+#include <tdelocale.h>
+#include <tdeconfig.h>
#include <kcursor.h>
#include <kdialog.h>
-#include <kglobal.h>
-#include <kapplication.h>
+#include <tdeglobal.h>
+#include <tdeapplication.h>
#include "backends/recipedb.h"
#include "refineshoppinglistdialog.h"
@@ -27,10 +27,10 @@
#include "recipeactionshandler.h"
/** A simple listview to accept dropping a RecipeItemDrag */
-class ShoppingListView : public KListView
+class ShoppingListView : public TDEListView
{
public:
- ShoppingListView( TQWidget *parent ) : KListView( parent )
+ ShoppingListView( TQWidget *parent ) : TDEListView( parent )
{}
protected:
@@ -71,22 +71,22 @@ ShoppingListDialog::ShoppingListDialog( TQWidget *parent, RecipeDB *db ) : TQWid
listview->setAcceptDrops( true );
listview->setDropVisualizer( false );
connect( recipeListView, SIGNAL( textChanged(const TQString&) ), SLOT( ensurePopulated() ) );
- connect( listview, SIGNAL( dropped( KListView*, TQDropEvent*, TQListViewItem* ) ),
- this, SLOT( slotDropped( KListView*, TQDropEvent*, TQListViewItem* ) ) );
+ connect( listview, SIGNAL( dropped( TDEListView*, TQDropEvent*, TQListViewItem* ) ),
+ this, SLOT( slotDropped( TDEListView*, TQDropEvent*, TQListViewItem* ) ) );
recipeListView->setListView( listview );
recipeListView->setCustomFilter( new RecipeFilter( recipeListView->listView() ), SLOT( filter( const TQString & ) ) );
recipeListView->setSizePolicy( TQSizePolicy::Minimum, TQSizePolicy::MinimumExpanding );
TQBoxLayout* vboxl = new TQVBoxLayout( KDialog::spacingHint() );
- KIconLoader il;
+ TDEIconLoader il;
addRecipeButton = new TQPushButton( this );
- addRecipeButton->setIconSet( il.loadIconSet( "forward", KIcon::Small ) );
+ addRecipeButton->setIconSet( il.loadIconSet( "forward", TDEIcon::Small ) );
addRecipeButton->setFixedSize( TQSize( 32, 32 ) );
addRecipeButton->setFlat( true );
vboxl->addWidget( addRecipeButton );
removeRecipeButton = new TQPushButton( this );
- removeRecipeButton->setIconSet( il.loadIconSet( "back", KIcon::Small ) );
+ removeRecipeButton->setIconSet( il.loadIconSet( "back", TDEIcon::Small ) );
removeRecipeButton->setFixedSize( TQSize( 32, 32 ) );
removeRecipeButton->setFlat( true );
vboxl->addWidget( removeRecipeButton );
@@ -100,14 +100,14 @@ ShoppingListDialog::ShoppingListDialog( TQWidget *parent, RecipeDB *db ) : TQWid
slistview->setDragEnabled( true );
slistview->setAcceptDrops( true );
slistview->setDropVisualizer( false );
- connect( slistview, SIGNAL( dropped( KListView*, TQDropEvent*, TQListViewItem* ) ),
- this, SLOT( slotDropped( KListView*, TQDropEvent*, TQListViewItem* ) ) );
+ connect( slistview, SIGNAL( dropped( TDEListView*, TQDropEvent*, TQListViewItem* ) ),
+ this, SLOT( slotDropped( TDEListView*, TQDropEvent*, TQListViewItem* ) ) );
shopRecipeListView->setListView( slistview );
layout->addWidget( shopRecipeListView, 0, 2 );
shopRecipeListView->listView() ->addColumn( i18n( "Recipe Title" ) );
- KConfig *config = KGlobal::config();
+ TDEConfig *config = TDEGlobal::config();
config->setGroup( "Advanced" );
bool show_id = config->readBoolEntry( "ShowID", false );
shopRecipeListView->listView() ->addColumn( i18n( "Id" ), show_id ? -1 : 0 );
@@ -125,14 +125,14 @@ ShoppingListDialog::ShoppingListDialog( TQWidget *parent, RecipeDB *db ) : TQWid
okButton = new TQPushButton( buttonBar, "okButton" );
okButton->setText( i18n( "&OK" ) );
- TQPixmap pm = il.loadIcon( "ok", KIcon::NoGroup, 16 );
+ TQPixmap pm = il.loadIcon( "ok", TDEIcon::NoGroup, 16 );
okButton->setIconSet( pm );
//buttonBar->layout()->addItem( new TQSpacerItem( 10,10, TQSizePolicy::MinimumExpanding, TQSizePolicy::Fixed ) );
clearButton = new TQPushButton( buttonBar, "clearButton" );
clearButton->setText( i18n( "Clear" ) );
- pm = il.loadIcon( "editclear", KIcon::NoGroup, 16 );
+ pm = il.loadIcon( "editclear", TDEIcon::NoGroup, 16 );
clearButton->setIconSet( pm );
//Takes care of all recipe actions and provides a popup menu to 'recipeListView'
@@ -236,7 +236,7 @@ void ShoppingListDialog::clear()
shopRecipeListView->listView() ->clear();
}
-void ShoppingListDialog::slotDropped( KListView *list, TQDropEvent *e, TQListViewItem * /*after*/ )
+void ShoppingListDialog::slotDropped( TDEListView *list, TQDropEvent *e, TQListViewItem * /*after*/ )
{
Recipe r;
RecipeListItem *item = new RecipeListItem( recipeListView->listView(), r ); // needs parent, use this temporarily
diff --git a/krecipes/src/dialogs/shoppinglistdialog.h b/krecipes/src/dialogs/shoppinglistdialog.h
index a0daa1d..3d82dfe 100644
--- a/krecipes/src/dialogs/shoppinglistdialog.h
+++ b/krecipes/src/dialogs/shoppinglistdialog.h
@@ -69,7 +69,7 @@ private slots:
void removeRecipe( void );
void showShoppingList( void );
void clear( void );
- void slotDropped( KListView *list, TQDropEvent *e, TQListViewItem *after );
+ void slotDropped( TDEListView *list, TQDropEvent *e, TQListViewItem *after );
void ensurePopulated();
};
diff --git a/krecipes/src/dialogs/shoppinglistviewdialog.cpp b/krecipes/src/dialogs/shoppinglistviewdialog.cpp
index 02ffe6c..c84b6cd 100644
--- a/krecipes/src/dialogs/shoppinglistviewdialog.cpp
+++ b/krecipes/src/dialogs/shoppinglistviewdialog.cpp
@@ -16,9 +16,9 @@
#include <ntqpushbutton.h>
-#include <klocale.h>
-#include <kapplication.h>
-#include <kconfig.h>
+#include <tdelocale.h>
+#include <tdeapplication.h>
+#include <tdeconfig.h>
#include <kiconloader.h>
ShoppingListViewDialog::ShoppingListViewDialog( TQWidget *parent, const IngredientList &ingredientList )
@@ -29,7 +29,7 @@ ShoppingListViewDialog::ShoppingListViewDialog( TQWidget *parent, const Ingredie
// Design dialog
TQVBox *page = makeVBoxMainWidget();
- shoppingListView = new KHTMLPart( page );
+ shoppingListView = new TDEHTMLPart( page );
setInitialSize( TQSize(350, 450) );
@@ -64,7 +64,7 @@ void ShoppingListViewDialog::display( const IngredientList &ingredientList )
recipeHTML += "<div STYLE=\"border:medium solid blue; width:95%\"><table cellspacing=0px width=100%><tbody>";
bool counter = true;
- KConfig *config = KGlobal::config();
+ TDEConfig *config = TDEGlobal::config();
config->setGroup( "Formatting" );
bool useAbbreviations = config->readBoolEntry("AbbreviateUnits");
diff --git a/krecipes/src/dialogs/shoppinglistviewdialog.h b/krecipes/src/dialogs/shoppinglistviewdialog.h
index 69a66a2..7ee404b 100644
--- a/krecipes/src/dialogs/shoppinglistviewdialog.h
+++ b/krecipes/src/dialogs/shoppinglistviewdialog.h
@@ -17,8 +17,8 @@
#include <ntqvbox.h>
#include <ntqwidget.h>
-#include <khtml_part.h>
-#include <khtmlview.h>
+#include <tdehtml_part.h>
+#include <tdehtmlview.h>
#include <kdialogbase.h>
class IngredientList;
@@ -37,7 +37,7 @@ public slots:
private:
// Widgets
- KHTMLPart *shoppingListView;
+ TDEHTMLPart *shoppingListView;
// Internal Methods
void display( const IngredientList &ingredientList );
diff --git a/krecipes/src/dialogs/similarcategoriesdialog.cpp b/krecipes/src/dialogs/similarcategoriesdialog.cpp
index 944dec0..f81e4ba 100644
--- a/krecipes/src/dialogs/similarcategoriesdialog.cpp
+++ b/krecipes/src/dialogs/similarcategoriesdialog.cpp
@@ -19,9 +19,9 @@
#include <ntqtooltip.h>
#include <ntqwhatsthis.h>
-#include <klistview.h>
-#include <klocale.h>
-#include <kmessagebox.h>
+#include <tdelistview.h>
+#include <tdelocale.h>
+#include <tdemessagebox.h>
#include <klineedit.h>
#include "widgets/categorycombobox.h"
@@ -72,7 +72,7 @@ SimilarCategoriesDialog::SimilarCategoriesDialog( ElementList &list, TQWidget* p
allLabel = new TQLabel( this, "allLabel" );
layout8->addWidget( allLabel );
- allListView = new KListView( this, "allListView" );
+ allListView = new TDEListView( this, "allListView" );
allListView->setSizePolicy( TQSizePolicy( (TQSizePolicy::SizeType)7, (TQSizePolicy::SizeType)7, 0, 1, allListView->sizePolicy().hasHeightForWidth() ) );
layout8->addWidget( allListView );
layout9->addLayout( layout8 );
@@ -93,7 +93,7 @@ SimilarCategoriesDialog::SimilarCategoriesDialog( ElementList &list, TQWidget* p
toMergeLabel = new TQLabel( this, "toMergeLabel" );
layout7->addWidget( toMergeLabel );
- toMergeListView = new KListView( this, "toMergeListView" );
+ toMergeListView = new TDEListView( this, "toMergeListView" );
toMergeListView->setSizePolicy( TQSizePolicy( (TQSizePolicy::SizeType)7, (TQSizePolicy::SizeType)7, 0, 1, toMergeListView->sizePolicy().hasHeightForWidth() ) );
layout7->addWidget( toMergeListView );
layout9->addLayout( layout7 );
diff --git a/krecipes/src/dialogs/similarcategoriesdialog.h b/krecipes/src/dialogs/similarcategoriesdialog.h
index 41a3e92..8b32011 100644
--- a/krecipes/src/dialogs/similarcategoriesdialog.h
+++ b/krecipes/src/dialogs/similarcategoriesdialog.h
@@ -25,7 +25,7 @@ class TQLabel;
class TQPushButton;
class TQListViewItem;
-class KListView;
+class TDEListView;
class KLineEdit;
class RecipeDB;
@@ -47,11 +47,11 @@ public:
TQLabel* categoryLabel;
TQPushButton* searchButton;
TQLabel* allLabel;
- KListView* allListView;
+ TDEListView* allListView;
TQPushButton* removeButton;
TQPushButton* addButton;
TQLabel* toMergeLabel;
- KListView* toMergeListView;
+ TDEListView* toMergeListView;
TQPushButton* mergeButton;
TQPushButton* cancelButton;
diff --git a/krecipes/src/dialogs/unitsdialog.cpp b/krecipes/src/dialogs/unitsdialog.cpp
index deb3162..c5f1994 100644
--- a/krecipes/src/dialogs/unitsdialog.cpp
+++ b/krecipes/src/dialogs/unitsdialog.cpp
@@ -20,11 +20,11 @@
#include "widgets/conversiontable.h"
#include "widgets/unitlistview.h"
-#include <kapplication.h>
+#include <tdeapplication.h>
#include <kdebug.h>
#include <kdialog.h>
-#include <klocale.h>
-#include <kmessagebox.h>
+#include <tdelocale.h>
+#include <tdemessagebox.h>
#include <kprogress.h>
UnitsDialog::UnitsDialog( TQWidget *parent, RecipeDB *db ) : TQWidget( parent )
diff --git a/krecipes/src/dialogs/unitsdialog.h b/krecipes/src/dialogs/unitsdialog.h
index 2056f90..d537a57 100644
--- a/krecipes/src/dialogs/unitsdialog.h
+++ b/krecipes/src/dialogs/unitsdialog.h
@@ -13,7 +13,7 @@
#ifndef UNITSDIALOG_H
#define UNITSDIALOG_H
#include <ntqwidget.h>
-#include <klistview.h>
+#include <tdelistview.h>
#include <ntqpushbutton.h>
#include "datablocks/unitratiolist.h"
diff --git a/krecipes/src/dialogs/usdadatadialog.cpp b/krecipes/src/dialogs/usdadatadialog.cpp
index b5bce00..dfdbfa8 100644
--- a/krecipes/src/dialogs/usdadatadialog.cpp
+++ b/krecipes/src/dialogs/usdadatadialog.cpp
@@ -13,9 +13,9 @@
#include <kdebug.h>
#include <kstandarddirs.h>
#include <klineedit.h>
-#include <klistview.h>
-#include <klocale.h>
-#include <kmessagebox.h>
+#include <tdelistview.h>
+#include <tdelocale.h>
+#include <tdemessagebox.h>
#include <ntqfile.h>
#include <ntqlabel.h>
diff --git a/krecipes/src/dialogs/usdadatadialog.h b/krecipes/src/dialogs/usdadatadialog.h
index 9ee9e48..dbde174 100644
--- a/krecipes/src/dialogs/usdadatadialog.h
+++ b/krecipes/src/dialogs/usdadatadialog.h
@@ -20,7 +20,7 @@
class RecipeDB;
-class KListView;
+class TDEListView;
class USDADataDialog : public KDialogBase
{
@@ -33,7 +33,7 @@ public:
private:
void loadDataFromFile();
- KListView *listView;
+ TDEListView *listView;
Element ingredient;
RecipeDB *database;
diff --git a/krecipes/src/dialogs/dietwizarddialog.cpp b/krecipes/src/dialogs/dietwizarddialog.cpp
index c07f25c..17f96d6 100644
--- a/krecipes/src/dialogs/dietwizarddialog.cpp
+++ b/krecipes/src/dialogs/dietwizarddialog.cpp
@@ -20,12 +20,12 @@
#include <ntqpainter.h>
#include <ntqwmatrix.h>
-#include <kapplication.h>
+#include <tdeapplication.h>
#include <kcursor.h>
-#include <kglobalsettings.h>
+#include <tdeglobalsettings.h>
#include <kiconloader.h>
-#include <klocale.h>
-#include <kmessagebox.h>
+#include <tdelocale.h>
+#include <tdemessagebox.h>
#include <knuminput.h>
#include <kdebug.h>
@@ -77,17 +77,17 @@ DietWizardDialog::DietWizardDialog( TQWidget *parent, RecipeDB *db ) : TQVBox( p
mealTabs->setMargin( 5 );
// Button bar
- KIconLoader il;
+ TDEIconLoader il;
TQHBox *bottom_layout = new TQHBox( this );
//bottom_layout->layout()->addItem( new TQSpacerItem( 10,10, TQSizePolicy::MinimumExpanding, TQSizePolicy::Fixed ) );
okButton = new TQPushButton( bottom_layout );
- okButton->setIconSet( il.loadIconSet( "button_ok", KIcon::Small ) );
+ okButton->setIconSet( il.loadIconSet( "button_ok", TDEIcon::Small ) );
okButton->setText( i18n( "Create the diet" ) );
TQPushButton *clearButton = new TQPushButton( bottom_layout );
- clearButton->setIconSet( il.loadIconSet( "editclear", KIcon::Small ) );
+ clearButton->setIconSet( il.loadIconSet( "editclear", TDEIcon::Small ) );
clearButton->setText( i18n( "Clear" ) );
// Create Tabs
@@ -179,7 +179,7 @@ void DietWizardDialog::changeDayNumber( int dn )
void DietWizardDialog::createDiet( void )
{
- KApplication::setOverrideCursor( KCursor::waitCursor() );
+ TDEApplication::setOverrideCursor( KCursor::waitCursor() );
START_TIMER("Creating the diet");
@@ -227,7 +227,7 @@ void DietWizardDialog::createDiet( void )
}
if ( alert ) {
- KApplication::restoreOverrideCursor();
+ TDEApplication::restoreOverrideCursor();
KMessageBox::sorry( this, i18n( "I could not create a full diet list given the constraints. Either the recipe list is too short or the constraints are too demanding. " ) );
}
@@ -242,7 +242,7 @@ void DietWizardDialog::createDiet( void )
dishNumbers << dishNo;
}
- KApplication::restoreOverrideCursor();
+ TDEApplication::restoreOverrideCursor();
// display the list
DietViewDialog dietDisplay( this, *dietRList, dayNumber, mealNumber, dishNumbers );
@@ -335,16 +335,16 @@ MealInput::MealInput( TQWidget *parent, RecipeDB *db ) : TQWidget( parent ),
toolBar->setSizePolicy( TQSizePolicy( TQSizePolicy::MinimumExpanding, TQSizePolicy::Minimum ) );
// Next dish/ Previous dish buttons
- KIconLoader il;
+ TDEIconLoader il;
buttonPrev = new TQToolButton( toolBar );
buttonPrev->setUsesTextLabel( true );
buttonPrev->setTextLabel( i18n( "Previous Dish" ) );
- buttonPrev->setIconSet( il.loadIconSet( "back", KIcon::Small ) );
+ buttonPrev->setIconSet( il.loadIconSet( "back", TDEIcon::Small ) );
buttonPrev->setTextPosition( TQToolButton::Under );
buttonNext = new TQToolButton( toolBar );
buttonNext->setUsesTextLabel( true );
buttonNext->setTextLabel( i18n( "Next Dish" ) );
- buttonNext->setIconSet( il.loadIconSet( "forward", KIcon::Small ) );
+ buttonNext->setIconSet( il.loadIconSet( "forward", TDEIcon::Small ) );
buttonNext->setTextPosition( TQToolButton::Under );
@@ -463,7 +463,7 @@ DishInput::DishInput( TQWidget* parent, RecipeDB *db, const TQString &title ) :
TQVBoxLayout *layout = new TQVBoxLayout( this );
layout->setSpacing( 10 );
//Horizontal Box to hold the KListView's
listBox = new TQHGroupBox( i18n( "Dish Characteristics" ), this );
layout->addWidget( listBox );
@@ -634,13 +634,13 @@ void DishTitle::paintEvent( TQPaintEvent * )
TQPainter painter( this );
// First draw the decoration
- painter.setPen( KGlobalSettings::activeTitleColor() );
- painter.setBrush( TQBrush( KGlobalSettings::activeTitleColor() ) );
+ painter.setPen( TDEGlobalSettings::activeTitleColor() );
+ painter.setBrush( TQBrush( TDEGlobalSettings::activeTitleColor() ) );
painter.drawRoundRect( 0, 20, 30, height() - 40, 50, ( int ) ( 50.0 / ( height() - 40 ) * 35.0 ) );
// Now draw the text
- TQFont titleFont = KGlobalSettings::windowTitleFont ();
+ TQFont titleFont = TDEGlobalSettings::windowTitleFont ();
titleFont.setPointSize( 15 );
painter.setFont( titleFont );
painter.rotate( -90 );
@@ -661,12 +661,12 @@ void DishTitle::paintEvent( TQPaintEvent * )
TQPainter painter( &pm );
// First draw the decoration
- painter.setPen( KGlobalSettings::activeTitleColor() );
- painter.setBrush( TQBrush( KGlobalSettings::activeTitleColor() ) );
+ painter.setPen( TDEGlobalSettings::activeTitleColor() );
+ painter.setBrush( TQBrush( TDEGlobalSettings::activeTitleColor() ) );
painter.drawRoundRect( 20, 0, height() - 40, 30, ( int ) ( 50.0 / ( height() - 40 ) * 35.0 ), 50 );
// Now draw the text
- TQFont titleFont = KGlobalSettings::windowTitleFont ();
+ TQFont titleFont = TDEGlobalSettings::windowTitleFont ();
titleFont.setPointSize( 15 );
painter.setFont( titleFont );
painter.setPen( TQColor( 0x00, 0x00, 0x00 ) );
@@ -753,21 +753,21 @@ void DietWizardDialog::loadConstraints( int meal, int dish, ConstraintList *cons
{
MealInput * mealTab = ( MealInput* ) ( mealTabs->page( meal ) ); // Get the meal
DishInput* dishInput = mealTab->dishInputList[ dish ]; // Get the dish input
- dishInput->loadConstraints( constraints ); //Load the constraints form the KListView
+ dishInput->loadConstraints( constraints ); //Load the constraints form the TDEListView
}
void DietWizardDialog::loadEnabledCategories( int meal, int dish, ElementList *categories )
{
MealInput * mealTab = ( MealInput* ) ( mealTabs->page( meal ) ); // Get the meal
DishInput* dishInput = mealTab->dishInputList[ dish ]; // Get the dish input
- dishInput->loadEnabledCategories( categories ); //Load the categories that have been checked in the KListView
+ dishInput->loadEnabledCategories( categories ); //Load the categories that have been checked in the TDEListView
}
bool DietWizardDialog::categoryFiltering( int meal, int dish ) const
{
MealInput * mealTab = ( MealInput* ) ( mealTabs->page( meal ) ); // Get the meal
DishInput* dishInput = mealTab->dishInputList[ dish ]; // Get the dish input
- return ( dishInput->isCategoryFilteringEnabled() ); //Load the categories that have been checked in the KListView
+ return ( dishInput->isCategoryFilteringEnabled() ); //Load the categories that have been checked in the TDEListView
}
bool DietWizardDialog::checkLimits( IngredientPropertyList &properties, ConstraintList &constraints )
@@ -463,7 +463,7 @@ DishInput::DishInput( TQWidget* parent, RecipeDB *db, const TQString &title ) :
TQVBoxLayout *layout = new TQVBoxLayout( this );
layout->setSpacing( 10 );
- //Horizontal Box to hold the KListView's
+ //Horizontal Box to hold the TDEListView's
listBox = new TQHGroupBox( i18n( "Dish Characteristics" ), this );
layout->addWidget( listBox );
diff --git a/krecipes/src/dialogs/recipeviewdialog.cpp b/krecipes/src/dialogs/recipeviewdialog.cpp
index d47d7cd..8918ac0 100644
--- a/krecipes/src/dialogs/recipeviewdialog.cpp
+++ b/krecipes/src/dialogs/recipeviewdialog.cpp
@@ -16,18 +16,18 @@
#include <ntqstyle.h>
#include <ntqfile.h>
-#include <kapplication.h>
+#include <tdeapplication.h>
#include <kcursor.h>
#include <kdebug.h>
-#include <khtmlview.h>
-#include <khtml_part.h>
-#include <klocale.h>
-#include <kmainwindow.h>
+#include <tdehtmlview.h>
+#include <tdehtml_part.h>
+#include <tdelocale.h>
+#include <tdemainwindow.h>
#include <kprogress.h>
#include <kstandarddirs.h>
#include <kstatusbar.h>
-#include <kconfig.h>
-#include <kglobal.h>
+#include <tdeconfig.h>
+#include <tdeglobal.h>
#include "datablocks/mixednumber.h"
#include "backends/recipedb.h"
@@ -38,7 +38,7 @@ RecipeViewDialog::RecipeViewDialog( TQWidget *parent, RecipeDB *db, int recipeID
database(db)
{
// Initialize UI Elements
- recipeView = new KHTMLPart( this );
+ recipeView = new TDEHTMLPart( this );
connect( database, SIGNAL(recipeRemoved(int)), SLOT(recipeRemoved(int)) );
@@ -64,7 +64,7 @@ bool RecipeViewDialog::loadRecipe( int recipeID )
bool RecipeViewDialog::loadRecipes( const TQValueList<int> &ids, const TQString &layoutConfig )
{
- KApplication::setOverrideCursor( KCursor::waitCursor() );
+ TDEApplication::setOverrideCursor( KCursor::waitCursor() );
// Remove any files created by the last recipe loaded
removeOldFiles();
@@ -74,7 +74,7 @@ bool RecipeViewDialog::loadRecipes( const TQValueList<int> &ids, const TQString
bool success = showRecipes( ids, layoutConfig );
- KApplication::restoreOverrideCursor();
+ TDEApplication::restoreOverrideCursor();
return success;
}
@@ -90,7 +90,7 @@ bool RecipeViewDialog::showRecipes( const TQValueList<int> &ids, const TQString
HTMLExporter html_generator( tmp_filename + ".html", "html" );
if ( layoutConfig != TQString::null ) {
- KConfig *config = KGlobal::config();
+ TDEConfig *config = TDEGlobal::config();
config->setGroup( "Page Setup" );
TQString styleFile = config->readEntry( layoutConfig+"Layout", locate( "appdata", "layouts/Default.klo" ) );
if ( !styleFile.isEmpty() && TQFile::exists( styleFile ) )
@@ -108,7 +108,7 @@ bool RecipeViewDialog::showRecipes( const TQValueList<int> &ids, const TQString
}
delete recipeView; // Temporary workaround
- recipeView = new KHTMLPart( this ); // to avoid the problem of caching images of KHTMLPart
+ recipeView = new TDEHTMLPart( this ); // to avoid the problem of caching images of TDEHTMLPart
KURL url;
url.setPath( tmp_filename + ".html" );
diff --git a/krecipes/src/dialogs/setupdisplay.h b/krecipes/src/dialogs/setupdisplay.h
index 83f761f..fd5f207 100644
--- a/krecipes/src/dialogs/setupdisplay.h
+++ b/krecipes/src/dialogs/setupdisplay.h
@@ -11,7 +11,7 @@
#ifndef SETUPDISPLAY_H
#define SETUPDISPLAY_H
-#include <khtml_part.h>
+#include <tdehtml_part.h>
#include <dom/html_element.h>
#include <dom/css_stylesheet.h>
@@ -25,7 +25,7 @@
#include <math.h>
-class KPopupMenu;
+class TDEPopupMenu;
class TQAction;
class TQLabel;
@@ -53,13 +53,13 @@ public:
typedef TQMap< KreDisplayItem*, unsigned int > PropertiesMap;
/** @brief A KHTMLPart for editing specific CSS properties
*
* Set up the items of a recipe for display.
*
* @author Jason Kivlighn
*/
-class SetupDisplay : public KHTMLPart, protected KLOManager
+class SetupDisplay : public TDEHTMLPart, protected KLOManager
{
Q_OBJECT
@@ -136,7 +136,7 @@ private:
//the item corresponding to the current point of processing the KLO
KreDisplayItem *m_currentItem;
- KPopupMenu *popup;
+ TDEPopupMenu *popup;
DOM::CSSStyleSheet m_styleSheet;
Recipe m_sample;
@@ -53,13 +53,13 @@ public:
typedef TQMap< KreDisplayItem*, unsigned int > PropertiesMap;
-/** @brief A KHTMLPart for editing specific CSS properties
+/** @brief A TDEHTMLPart for editing specific CSS properties
*
* Set up the items of a recipe for display.